@@ -29,4 +29,7 @@ import java.io.Serializable;
 public interface SchemaChangeEvent extends ChangeEvent, Serializable {
     /** Returns its {@link SchemaChangeEventType}. */
     SchemaChangeEventType getType();
+
+    /** Creates a copy of {@link SchemaChangeEvent} with new {@link TableId}. */
+    SchemaChangeEvent copy(TableId newTableId);
 }
