@@ -41,11 +41,13 @@ import javax.annotation.CheckReturnValue;
 import javax.annotation.Nullable;
 
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
+import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
@@ -75,6 +77,19 @@ public class SchemaUtils {
         return fieldGetters;
     }
 
+    /**
+     * create a list of {@link RecordData.FieldGetter} from given {@link Column} to get Object from
+     * RecordData.
+     */
+    @CheckReturnValue
+    public static List<RecordData.FieldGetter> createFieldGetters(DataType[] dataTypes) {
+        List<RecordData.FieldGetter> fieldGetters = new ArrayList<>(dataTypes.length);
+        for (int i = 0; i < dataTypes.length; i++) {
+            fieldGetters.add(RecordData.createFieldGetter(dataTypes[i], i));
+        }
+        return fieldGetters;
+    }
+
     /** Restore original data fields from RecordData structure. */
     @CheckReturnValue
     public static List<Object> restoreOriginalData(
@@ -376,6 +391,20 @@ public class SchemaUtils {
                         }));
     }
 
+    @CheckReturnValue
+    public static Schema ensurePkNonNull(Schema schema) {
+        Set<String> pkColumns = new HashSet<>(schema.primaryKeys());
+        List<Column> columns =
+                schema.getColumns().stream()
+                        .map(
+                                col ->
+                                        pkColumns.contains(col.getName())
+                                                ? col.copy(col.getType().notNull())
+                                                : col)
+                        .collect(Collectors.toList());
+        return schema.copy(columns);
+    }
+
     // Schema merging related utility methods have been moved to SchemaMergingUtils class.
     // The following methods have been deprecated and should not be used.
 
