@@ -45,6 +45,7 @@ import org.apache.flink.util.CollectionUtil;
 
 import org.apache.flink.shaded.guava31.com.google.common.collect.Sets;
 
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.doris.flink.catalog.DorisTypeMapper;
 import org.apache.doris.flink.catalog.doris.DataModel;
 import org.apache.doris.flink.catalog.doris.FieldSchema;
@@ -149,17 +150,15 @@ public class DorisMetadataApplier implements MetadataApplier {
             TableSchema tableSchema = new TableSchema();
             tableSchema.setTable(tableId.getTableName());
             tableSchema.setDatabase(tableId.getSchemaName());
+            tableSchema.setModel(
+                    CollectionUtils.isEmpty(schema.primaryKeys())
+                            ? DataModel.DUPLICATE
+                            : DataModel.UNIQUE);
             tableSchema.setFields(buildFields(schema));
+            tableSchema.setKeys(buildKeys(schema));
             tableSchema.setDistributeKeys(buildDistributeKeys(schema));
             tableSchema.setTableComment(schema.comment());
 
-            if (CollectionUtil.isNullOrEmpty(schema.primaryKeys())) {
-                tableSchema.setModel(DataModel.DUPLICATE);
-            } else {
-                tableSchema.setKeys(schema.primaryKeys());
-                tableSchema.setModel(DataModel.UNIQUE);
-            }
-
             Map<String, String> tableProperties =
                     DorisDataSinkOptions.getPropertiesByPrefix(
                             config, TABLE_CREATE_PROPERTIES_PREFIX);
@@ -200,12 +199,17 @@ public class DorisMetadataApplier implements MetadataApplier {
                     new FieldSchema(
                             column.getName(),
                             typeString,
-                            column.getDefaultValueExpression(),
+                            convertInvalidTimestampDefaultValue(
+                                    column.getDefaultValueExpression(), column.getType()),
                             column.getComment()));
         }
         return fieldSchemaMap;
     }
 
+    private List<String> buildKeys(Schema schema) {
+        return buildDistributeKeys(schema);
+    }
+
     private List<String> buildDistributeKeys(Schema schema) {
         if (!CollectionUtil.isNullOrEmpty(schema.primaryKeys())) {
             return schema.primaryKeys();
@@ -237,7 +241,8 @@ public class DorisMetadataApplier implements MetadataApplier {
                         new FieldSchema(
                                 column.getName(),
                                 buildTypeString(column.getType()),
-                                column.getDefaultValueExpression(),
+                                convertInvalidTimestampDefaultValue(
+                                        column.getDefaultValueExpression(), column.getType()),
                                 column.getComment());
                 schemaChangeManager.addColumn(
                         tableId.getSchemaName(), tableId.getTableName(), addFieldSchema);
@@ -316,4 +321,21 @@ public class DorisMetadataApplier implements MetadataApplier {
             throw new SchemaEvolveException(dropTableEvent, "fail to drop table", e);
         }
     }
+
+    private String convertInvalidTimestampDefaultValue(String defaultValue, DataType dataType) {
+        if (defaultValue == null) {
+            return null;
+        }
+
+        if (dataType instanceof LocalZonedTimestampType
+                || dataType instanceof TimestampType
+                || dataType instanceof ZonedTimestampType) {
+
+            if (DorisSchemaUtils.INVALID_OR_MISSING_DATATIME.equals(defaultValue)) {
+                return DorisSchemaUtils.DEFAULT_DATETIME;
+            }
+        }
+
+        return defaultValue;
+    }
 }
