@@ -65,7 +65,7 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 /** ITCase tests for {@link ElasticsearchDataSink}. */
 @Testcontainers
-public class ElasticsearchDataSinkITCaseTest {
+class ElasticsearchDataSinkITCaseTest {
 
     private static final Logger LOG =
             LoggerFactory.getLogger(ElasticsearchDataSinkITCaseTest.class);
@@ -92,7 +92,7 @@ public class ElasticsearchDataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchSink() throws Exception {
+    void testElasticsearchSink() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEvents(tableId);
 
@@ -127,7 +127,7 @@ public class ElasticsearchDataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchInsertAndDelete() throws Exception {
+    void testElasticsearchInsertAndDelete() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEventsWithDelete(tableId);
 
@@ -137,7 +137,7 @@ public class ElasticsearchDataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchAddColumn() throws Exception {
+    void testElasticsearchAddColumn() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEventsWithAddColumn(tableId);
 
@@ -250,8 +250,9 @@ public class ElasticsearchDataSinkITCaseTest {
         assertThat(((Number) response.source().get("id")).intValue()).isEqualTo(expectedId);
         assertThat(((Number) response.source().get("number")).doubleValue())
                 .isEqualTo(expectedNumber);
-        assertThat(response.source().get("name")).isEqualTo(expectedName);
-        assertThat(response.source().get("bool")).isEqualTo(expectedBool);
+        assertThat(response.source())
+                .containsEntry("name", expectedName)
+                .containsEntry("bool", expectedBool);
         assertThat(((Number) response.source().get("tinyint")).byteValue())
                 .isEqualTo(expectedTinyint);
         assertThat(((Number) response.source().get("smallint")).shortValue())
@@ -287,10 +288,11 @@ public class ElasticsearchDataSinkITCaseTest {
         GetRequest getRequest = new GetRequest.Builder().index(tableId.toString()).id(id).build();
         GetResponse<Map> response = client.get(getRequest, Map.class);
 
-        assertThat(response.source()).isNotNull();
-        assertThat(response.source().get("id")).isEqualTo(expectedId);
-        assertThat(response.source().get("number")).isEqualTo(expectedNumber);
-        assertThat(response.source().get("name")).isEqualTo(expectedName);
-        assertThat(response.source().get("extra_bool")).isEqualTo(expectedExtraBool);
+        assertThat(response.source())
+                .isNotNull()
+                .containsEntry("id", expectedId)
+                .containsEntry("number", expectedNumber)
+                .containsEntry("name", expectedName)
+                .containsEntry("extra_bool", expectedExtraBool);
     }
 }
