@@ -18,8 +18,10 @@
 
 package org.apache.flink.cdc.connectors.maxcompute.utils;
 
+import org.apache.flink.cdc.common.data.DateData;
 import org.apache.flink.cdc.common.data.DecimalData;
 import org.apache.flink.cdc.common.data.LocalZonedTimestampData;
+import org.apache.flink.cdc.common.data.TimeData;
 import org.apache.flink.cdc.common.data.TimestampData;
 import org.apache.flink.cdc.common.data.ZonedTimestampData;
 import org.apache.flink.cdc.common.data.binary.BinaryRecordData;
@@ -165,8 +167,8 @@ class TypeConvertUtilsTest {
                             12345L,
                             123.456f,
                             123456.789d,
-                            12345,
-                            12345,
+                            TimeData.fromMillisOfDay(1234567),
+                            DateData.fromEpochDay(12345),
                             TimestampData.fromTimestamp(Timestamp.valueOf("1970-01-01 00:00:00")),
                             LocalZonedTimestampData.fromInstant(Instant.ofEpochSecond(0)),
                             ZonedTimestampData.fromZonedDateTime(
@@ -179,7 +181,7 @@ class TypeConvertUtilsTest {
         TypeConvertUtils.toMaxComputeRecord(schemaWithoutComplexType, record1, arrayRecord);
 
         String expect =
-                "char,varchar,string,false,=01=02=03=04=05,=01=02=03=04=05=06=07=08=09=0A,0.00,1,2,12345,12345,123.456,123456.789,00:00:00.012345,2003-10-20,1970-01-01T00:00,1970-01-01T00:00:00Z,1970-01-01T00:00:00Z";
+                "char,varchar,string,false,=01=02=03=04=05,=01=02=03=04=05=06=07=08=09=0A,0.00,1,2,12345,12345,123.456,123456.789,00:20:34.567,2003-10-20,1970-01-01T00:00,1970-01-01T00:00:00Z,1970-01-01T00:00:00Z";
         assertThat(arrayRecord).hasToString(expect);
     }
 }
