@@ -36,11 +36,14 @@ public class CustomMySqlAntlrDdlParser extends MySqlAntlrDdlParser {
 
     private final LinkedList<SchemaChangeEvent> parsedEvents;
     private final boolean tinyInt1isBit;
+    private boolean isTableIdCaseInsensitive;
 
-    public CustomMySqlAntlrDdlParser(boolean includeComments, boolean tinyInt1isBit) {
+    public CustomMySqlAntlrDdlParser(
+            boolean includeComments, boolean tinyInt1isBit, boolean isTableIdCaseInsensitive) {
         super(true, false, includeComments, null, Tables.TableFilter.includeAll());
         this.parsedEvents = new LinkedList<>();
         this.tinyInt1isBit = tinyInt1isBit;
+        this.isTableIdCaseInsensitive = isTableIdCaseInsensitive;
     }
 
     // Overriding this method because the BIT type requires default length dimension of 1.
@@ -280,7 +283,8 @@ public class CustomMySqlAntlrDdlParser extends MySqlAntlrDdlParser {
 
     @Override
     protected AntlrDdlParserListener createParseTreeWalkerListener() {
-        return new CustomMySqlAntlrDdlParserListener(this, parsedEvents, tinyInt1isBit);
+        return new CustomMySqlAntlrDdlParserListener(
+                this, parsedEvents, tinyInt1isBit, isTableIdCaseInsensitive);
     }
 
     public List<SchemaChangeEvent> getAndClearParsedEvents() {
