@@ -19,9 +19,11 @@ package org.apache.flink.cdc.connectors.mysql.source;
 
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.api.common.restartstrategy.RestartStrategies;
+import org.apache.flink.cdc.common.data.DateData;
 import org.apache.flink.cdc.common.data.DecimalData;
 import org.apache.flink.cdc.common.data.LocalZonedTimestampData;
 import org.apache.flink.cdc.common.data.RecordData;
+import org.apache.flink.cdc.common.data.TimeData;
 import org.apache.flink.cdc.common.data.TimestampData;
 import org.apache.flink.cdc.common.data.binary.BinaryStringData;
 import org.apache.flink.cdc.common.event.DataChangeEvent;
@@ -159,13 +161,10 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                 new Object[] {
                     DecimalData.fromBigDecimal(new BigDecimal("1"), 20, 0),
                     2021,
-                    18460,
-                    64822000,
-                    64822123,
-                    // TIME(6) will lose precision for microseconds.
-                    // Because Flink's BinaryWriter force write int value for TIME(6).
-                    // See BinaryWriter#write for detail.
-                    64822123,
+                    DateData.fromEpochDay(18460),
+                    TimeData.fromNanoOfDay(64822000_000_000L),
+                    TimeData.fromNanoOfDay(64822123_000_000L),
+                    TimeData.fromNanoOfDay(64822123_456_000L),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123456")),
@@ -177,9 +176,9 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                 new Object[] {
                     DecimalData.fromBigDecimal(new BigDecimal("1"), 20, 0),
                     2021,
-                    18460,
-                    64822000,
-                    64822123,
+                    DateData.fromEpochDay(18460),
+                    TimeData.fromNanoOfDay(64822000_000_000L),
+                    TimeData.fromNanoOfDay(64822123_000_000L),
                     null,
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123")),
@@ -194,6 +193,7 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
 
     @Test
     void testMysql8TimeDataTypes() throws Throwable {
+        UniqueDatabase usedDd = fullTypesMySql8Database;
         RowType recordType =
                 RowType.of(
                         DataTypes.DECIMAL(20, 0).notNull(),
@@ -214,13 +214,10 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                 new Object[] {
                     DecimalData.fromBigDecimal(new BigDecimal("1"), 20, 0),
                     2021,
-                    18460,
-                    64822000,
-                    64822123,
-                    // TIME(6) will lose precision for microseconds.
-                    // Because Flink's BinaryWriter force write int value for TIME(6).
-                    // See BinaryWriter#write for detail.
-                    64822123,
+                    DateData.fromEpochDay(18460),
+                    TimeData.fromNanoOfDay(64822000_000_000L),
+                    TimeData.fromNanoOfDay(64822123_000_000L),
+                    TimeData.fromNanoOfDay(64822123_456_000L),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123456")),
@@ -234,9 +231,9 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                 new Object[] {
                     DecimalData.fromBigDecimal(new BigDecimal("1"), 20, 0),
                     2021,
-                    18460,
-                    64822000,
-                    64822123,
+                    DateData.fromEpochDay(18460),
+                    TimeData.fromNanoOfDay(64822000_000_000L),
+                    TimeData.fromNanoOfDay(64822123_000_000L),
                     null,
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22.123")),
@@ -247,8 +244,7 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                     LocalZonedTimestampData.fromInstant(toInstant("2000-01-01 00:00:00"))
                 };
 
-        testTimeDataTypes(
-                fullTypesMySql8Database, recordType, expectedSnapshot, expectedStreamRecord);
+        testTimeDataTypes(usedDd, recordType, expectedSnapshot, expectedStreamRecord);
     }
 
     @Test
@@ -296,9 +292,9 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                     DecimalData.fromBigDecimal(new BigDecimal("123.4"), 6, 2),
                     DecimalData.fromBigDecimal(new BigDecimal("1234.5"), 9, 4),
                     DecimalData.fromBigDecimal(new BigDecimal("1234.56"), 20, 4),
-                    64800000,
-                    64822100,
-                    64822100,
+                    TimeData.fromNanoOfDay(64800000_000_000L),
+                    TimeData.fromNanoOfDay(64822100_000_000L),
+                    TimeData.fromNanoOfDay(64822100_000_000L),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:00")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
@@ -325,8 +321,8 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                     DecimalData.fromBigDecimal(new BigDecimal("123.4"), 6, 2),
                     DecimalData.fromBigDecimal(new BigDecimal("1234.5"), 9, 4),
                     DecimalData.fromBigDecimal(new BigDecimal("1234.56"), 20, 4),
-                    64800000,
-                    64822100,
+                    TimeData.fromNanoOfDay(64800000_000_000L),
+                    TimeData.fromNanoOfDay(64822100_000_000L),
                     null,
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:00")),
                     TimestampData.fromTimestamp(Timestamp.valueOf("2020-07-17 18:00:22")),
@@ -468,7 +464,10 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                     BinaryStringData.fromString(expectMultipointJsonText),
                     BinaryStringData.fromString(expectMultilineJsonText),
                     BinaryStringData.fromString(expectMultipolygonJsonText),
-                    BinaryStringData.fromString(expectGeometryCollectionJsonText)
+                    BinaryStringData.fromString(expectGeometryCollectionJsonText),
+                    BinaryStringData.fromString("long"),
+                    BinaryStringData.fromString("long varchar"),
+                    BinaryStringData.fromString("")
                 };
 
         // skip CreateTableEvent
@@ -679,6 +678,9 @@ class MySqlFullTypesITCase extends MySqlSourceTestBase {
                     DataTypes.STRING(),
                     DataTypes.STRING(),
                     DataTypes.STRING(),
+                    DataTypes.STRING(),
+                    DataTypes.STRING(),
+                    DataTypes.STRING(),
                     DataTypes.STRING());
 
     private static final RowType JSON_TYPES =
