@@ -166,6 +166,23 @@ class MySqlTablePatternMatchingTest extends MySqlSourceTestBase {
                 .containsExactlyInAnyOrder("db\\.tbl1|db2\\.tbl.*|db3\\.tbl3");
     }
 
+    @Test
+    void testMatchingTablesWithSpacedRules() {
+        List<String> spacedRules =
+                Arrays.asList(
+                        "db.tbl1, db2.tbl\\.*, db3.tbl3",
+                        "db.tbl1 ,db2.tbl\\.* ,db3.tbl3",
+                        "db.tbl1 , db2.tbl\\.* , db3.tbl3");
+
+        Assertions.assertThat(spacedRules)
+                .map(rule -> testGenericTableMatching(rule, null, false))
+                .containsOnly(Arrays.asList("db.tbl1", "db2.tbl2", "db3.tbl3"));
+
+        Assertions.assertThat(spacedRules)
+                .map(rule -> testGenericTableMatching(rule, null, true))
+                .containsOnly(Arrays.asList("db\\.tbl1|db2\\.tbl.*|db3\\.tbl3"));
+    }
+
     @Test
     void testWildcardMatchingRealTables() throws Exception {
         String[] expected =
@@ -280,6 +297,29 @@ class MySqlTablePatternMatchingTest extends MySqlSourceTestBase {
                 .containsExactlyInAnyOrder(expected);
     }
 
+    @Test
+    void testMatchingRealTablesWithSpacedRules() throws Exception {
+        String[] expected =
+                new String[] {
+                    "CreateTableEvent{tableId=db.tbl1, schema=columns={`id` INT NOT NULL}, primaryKeys=id, options=()}",
+                    "DataChangeEvent{tableId=db.tbl1, before=[], after=[17], op=INSERT, meta=()}",
+                    "CreateTableEvent{tableId=db2.tbl2, schema=columns={`id` INT NOT NULL}, primaryKeys=id, options=()}",
+                    "DataChangeEvent{tableId=db2.tbl2, before=[], after=[17], op=INSERT, meta=()}",
+                    "CreateTableEvent{tableId=db3.tbl3, schema=columns={`id` INT NOT NULL}, primaryKeys=id, options=()}",
+                    "DataChangeEvent{tableId=db3.tbl3, before=[], after=[17], op=INSERT, meta=()}"
+                };
+
+        Assertions.assertThat(
+                        getRealWorldMatchedTables(
+                                "db.tbl1 , db2.tbl\\.* , db3.tbl3", null, false, expected.length))
+                .containsExactlyInAnyOrder(expected);
+
+        Assertions.assertThat(
+                        getRealWorldMatchedTables(
+                                "db.tbl1 , db2.tbl\\.* , db3.tbl3", null, true, expected.length))
+                .containsExactlyInAnyOrder(expected);
+    }
+
     private static void initializeMySqlTables(List<Tuple2<String, String>> tableNames) {
         tableNames.forEach(
                 tableName -> {
