@@ -25,8 +25,10 @@ import org.apache.flink.runtime.io.disk.iomanager.IOManager;
 import org.apache.flink.runtime.io.disk.iomanager.IOManagerAsync;
 import org.apache.flink.streaming.api.operators.StreamOperator;
 
+import org.apache.paimon.CoreOptions;
 import org.apache.paimon.catalog.Catalog;
 import org.apache.paimon.catalog.Identifier;
+import org.apache.paimon.data.GenericRow;
 import org.apache.paimon.flink.FlinkCatalogFactory;
 import org.apache.paimon.flink.sink.MultiTableCommittable;
 import org.apache.paimon.flink.sink.StoreSinkWrite;
@@ -35,9 +37,10 @@ import org.apache.paimon.memory.MemoryPoolFactory;
 import org.apache.paimon.options.Options;
 import org.apache.paimon.table.FileStoreTable;
 import org.apache.paimon.utils.ExecutorThreadFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
@@ -50,6 +53,8 @@ import java.util.stream.Collectors;
 public class PaimonWriter<InputT>
         implements TwoPhaseCommittingSink.PrecommittingSinkWriter<InputT, MultiTableCommittable> {
 
+    private static final Logger LOG = LoggerFactory.getLogger(PaimonWriter.class);
+
     // use `static` because Catalog is unSerializable.
     private static Catalog catalog;
     private final IOManager ioManager;
@@ -91,22 +96,32 @@ public class PaimonWriter<InputT>
     }
 
     @Override
-    public Collection<MultiTableCommittable> prepareCommit() throws IOException {
-        List<MultiTableCommittable> committables = new ArrayList<>();
-        for (Map.Entry<Identifier, StoreSinkWrite> entry : writes.entrySet()) {
-            Identifier key = entry.getKey();
-            StoreSinkWrite write = entry.getValue();
-            boolean waitCompaction = true;
-            committables.addAll(
-                    // here we set it to lastCheckpointId+1 to
-                    // avoid prepareCommit the same checkpointId with the first round.
-                    write.prepareCommit(waitCompaction, lastCheckpointId + 1).stream()
-                            .map(
-                                    committable ->
-                                            MultiTableCommittable.fromCommittable(key, committable))
-                            .collect(Collectors.toList()));
-        }
+    public Collection<MultiTableCommittable> prepareCommit() {
+        long startTime = System.currentTimeMillis();
+        List<MultiTableCommittable> committables =
+                writes.entrySet()
+                        .parallelStream()
+                        .flatMap(
+                                entry -> {
+                                    try {
+                                        // here we set it to lastCheckpointId+1 to
+                                        // avoid prepareCommit the same checkpointId with the first
+                                        // round.
+                                        return entry.getValue()
+                                                .prepareCommit(false, lastCheckpointId + 1).stream()
+                                                .map(
+                                                        committable ->
+                                                                MultiTableCommittable
+                                                                        .fromCommittable(
+                                                                                entry.getKey(),
+                                                                                committable));
+                                    } catch (IOException e) {
+                                        throw new RuntimeException(e);
+                                    }
+                                })
+                        .collect(Collectors.toList());
         lastCheckpointId++;
+        LOG.debug("Spend {} ms to prepareCommit", System.currentTimeMillis() - startTime);
         return committables;
     }
 
@@ -126,7 +141,7 @@ public class PaimonWriter<InputT>
                 throw new RuntimeException(e);
             }
         }
-        if (paimonEvent.getGenericRow() != null) {
+        if (paimonEvent.getGenericRows() != null) {
             FileStoreTable table;
             table = getTable(tableId);
             if (memoryPoolFactory == null) {
@@ -141,13 +156,22 @@ public class PaimonWriter<InputT>
                     writes.computeIfAbsent(
                             tableId,
                             id -> {
+                                boolean waitCompaction =
+                                        Boolean.parseBoolean(
+                                                table.options()
+                                                        .getOrDefault(
+                                                                CoreOptions.DELETION_VECTORS_ENABLED
+                                                                        .key(),
+                                                                CoreOptions.DELETION_VECTORS_ENABLED
+                                                                        .defaultValue()
+                                                                        .toString()));
                                 StoreSinkWriteImpl storeSinkWrite =
                                         new StoreSinkWriteImpl(
                                                 table,
                                                 commitUser,
                                                 ioManager,
                                                 false,
-                                                false,
+                                                waitCompaction,
                                                 true,
                                                 memoryPoolFactory,
                                                 metricGroup);
@@ -155,7 +179,9 @@ public class PaimonWriter<InputT>
                                 return storeSinkWrite;
                             });
             try {
-                write.write(paimonEvent.getGenericRow(), paimonEvent.getBucket());
+                for (GenericRow genericRow : paimonEvent.getGenericRows()) {
+                    write.write(genericRow, paimonEvent.getBucket());
+                }
             } catch (Exception e) {
                 throw new IOException(e);
             }
