@@ -118,7 +118,7 @@ public class StoreSinkWriteImpl implements StoreSinkWrite {
                 "memoryPool and memoryPoolFactory cannot be set at the same time.");
 
         TableWriteImpl<?> tableWrite =
-                table.newWrite(commitUser, (part, bucket) -> true)
+                table.newWrite(commitUser, (part, bucket) -> true, null)
                         .withIOManager(paimonIOManager)
                         .withIgnorePreviousFiles(ignorePreviousFiles);
 
@@ -142,9 +142,6 @@ public class StoreSinkWriteImpl implements StoreSinkWrite {
         write.withCompactExecutor(compactExecutor);
     }
 
-    @Override
-    public void withInsertOnly(boolean b) {}
-
     @Override
     public SinkRecord write(InternalRow internalRow) throws Exception {
         return write.writeAndReturn(internalRow);
