@@ -40,7 +40,6 @@ import org.apache.flink.cdc.common.types.VarCharType;
 import com.starrocks.connector.flink.catalog.StarRocksColumn;
 import com.starrocks.connector.flink.catalog.StarRocksTable;
 
-import java.time.LocalDate;
 import java.time.ZoneId;
 import java.time.ZonedDateTime;
 import java.time.format.DateTimeFormatter;
@@ -53,6 +52,9 @@ import static org.apache.flink.cdc.common.types.DataTypeChecks.getScale;
 /** Utilities for conversion from source table to StarRocks table. */
 public class StarRocksUtils {
 
+    public static final String DEFAULT_DATETIME = "1970-01-01 00:00:00";
+    public static final String INVALID_OR_MISSING_DATATIME = "0000-00-00 00:00:00";
+
     /** Convert a source table to {@link StarRocksTable}. */
     public static StarRocksTable toStarRocksTable(
             TableId tableId, Schema schema, TableCreateConfig tableCreateConfig) {
@@ -85,7 +87,9 @@ public class StarRocksUtils {
                             .setColumnName(column.getName())
                             .setOrdinalPosition(i)
                             .setColumnComment(column.getComment())
-                            .setDefaultValue(column.getDefaultValueExpression());
+                            .setDefaultValue(
+                                    convertInvalidTimestampDefaultValue(
+                                            column.getDefaultValueExpression(), column.getType()));
             toStarRocksDataType(column, i < primaryKeyCount, builder);
             starRocksColumns.add(builder.build());
         }
@@ -172,9 +176,7 @@ public class StarRocksUtils {
                 break;
             case DATE:
                 fieldGetter =
-                        record ->
-                                LocalDate.ofEpochDay(record.getInt(fieldPos))
-                                        .format(DATE_FORMATTER);
+                        record -> record.getDate(fieldPos).toLocalDate().format(DATE_FORMATTER);
                 break;
             case TIMESTAMP_WITHOUT_TIME_ZONE:
                 fieldGetter =
@@ -386,4 +388,22 @@ public class StarRocksUtils {
             throw new UnsupportedOperationException("Unsupported CDC data type " + dataType);
         }
     }
+
+    public static String convertInvalidTimestampDefaultValue(
+            String defaultValue, org.apache.flink.cdc.common.types.DataType dataType) {
+        if (defaultValue == null) {
+            return null;
+        }
+
+        if (dataType instanceof org.apache.flink.cdc.common.types.LocalZonedTimestampType
+                || dataType instanceof org.apache.flink.cdc.common.types.TimestampType
+                || dataType instanceof org.apache.flink.cdc.common.types.ZonedTimestampType) {
+
+            if (INVALID_OR_MISSING_DATATIME.equals(defaultValue)) {
+                return DEFAULT_DATETIME;
+            }
+        }
+
+        return defaultValue;
+    }
 }
