@@ -131,7 +131,11 @@ public class SplitVectorSplitStrategy implements SplitStrategy {
                         ChunkUtils.maxUpperBoundOfId(),
                         null,
                         schema);
-        snapshotSplits.add(lastSplit);
+        if (splitContext.isAssignUnboundedChunkFirst()) {
+            snapshotSplits.add(0, lastSplit);
+        } else {
+            snapshotSplits.add(lastSplit);
+        }
 
         return snapshotSplits;
     }
