@@ -35,15 +35,13 @@ import com.mongodb.client.MongoDatabase;
 import com.mongodb.client.model.Filters;
 import com.mongodb.client.model.Updates;
 import org.bson.Document;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.rules.Timeout;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.io.TempDir;
 
+import java.nio.file.Path;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -57,7 +55,6 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
 import static java.lang.String.format;
 import static org.apache.flink.cdc.connectors.mongodb.utils.MongoDBContainer.FLINK_USER;
@@ -65,34 +62,25 @@ import static org.apache.flink.cdc.connectors.mongodb.utils.MongoDBContainer.FLI
 import static org.apache.flink.util.Preconditions.checkState;
 
 /** IT tests to cover various newly added collections during capture process. */
-@RunWith(Parameterized.class)
-public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
-
-    @Rule public final Timeout timeoutPerTest = Timeout.seconds(500);
+@Timeout(value = 500, unit = TimeUnit.SECONDS)
+class NewlyAddedTableITCase extends MongoDBSourceTestBase {
 
     private String customerDatabase;
     protected static final int DEFAULT_PARALLELISM = 4;
 
-    public NewlyAddedTableITCase(String mongoVersion) {
-        super(mongoVersion);
-    }
-
-    @Parameterized.Parameters(name = "mongoVersion: {0}")
-    public static Object[] parameters() {
-        return Stream.of(getMongoVersions()).map(e -> new Object[] {e}).toArray();
-    }
+    @TempDir private static Path tempDir;
 
     private final ScheduledExecutorService mockChangelogExecutor =
             Executors.newScheduledThreadPool(1);
 
-    @Before
+    @BeforeEach
     public void before() throws SQLException {
         customerDatabase = "customer_" + Integer.toUnsignedString(new Random().nextInt(), 36);
         TestValuesTableFactory.clearAllData();
         // prepare initial data for given collection
         String collectionName = "produce_changelog";
         // enable system-level fulldoc pre & post image feature
-        mongoContainer.executeCommand(
+        MONGO_CONTAINER.executeCommand(
                 "use admin; db.runCommand({ setClusterParameter: { changeStreamOptions: { preAndPostImages: { expireAfterSeconds: 'off' } } } })");
 
         // mock continuous changelog during the newly added collections capturing process
@@ -110,15 +98,18 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                 TimeUnit.MICROSECONDS);
     }
 
-    @After
+    @AfterEach
     public void after() {
         mockChangelogExecutor.shutdown();
-        MongoDatabase mongoDatabase = mongodbClient.getDatabase(customerDatabase);
-        mongoDatabase.drop();
+        if (mongodbClient != null) {
+            MongoDatabase mongoDatabase = mongodbClient.getDatabase(customerDatabase);
+            mongoDatabase.drop();
+        }
+        miniClusterResource.get().cancelAllJobs();
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineOnce() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineOnce() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -129,7 +120,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineOnceWithAheadOplog() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineOnceWithAheadOplog() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -140,7 +131,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineTwice() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineTwice() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -152,7 +143,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineTwiceWithAheadOplog() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineTwiceWithAheadOplog() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -164,7 +155,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineTwiceWithAheadOplogAndAutoCloseReader()
+    void testNewlyAddedCollectionForExistsPipelineTwiceWithAheadOplogAndAutoCloseReader()
             throws Exception {
         Map<String, String> otherOptions = new HashMap<>();
         otherOptions.put("scan.incremental.close-idle-reader.enabled", "true");
@@ -180,7 +171,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineThrice() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineThrice() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -193,7 +184,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineThriceWithAheadOplog() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineThriceWithAheadOplog() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -206,7 +197,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineSingleParallelism() throws Exception {
+    void testNewlyAddedCollectionForExistsPipelineSingleParallelism() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -217,7 +208,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testNewlyAddedCollectionForExistsPipelineSingleParallelismWithAheadOplog()
+    void testNewlyAddedCollectionForExistsPipelineSingleParallelismWithAheadOplog()
             throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
@@ -229,7 +220,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForNewlyAddedCollection() throws Exception {
+    void testJobManagerFailoverForNewlyAddedCollection() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.JM,
@@ -240,7 +231,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForNewlyAddedCollectionWithAheadOplog() throws Exception {
+    void testJobManagerFailoverForNewlyAddedCollectionWithAheadOplog() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.JM,
@@ -251,7 +242,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForNewlyAddedCollection() throws Exception {
+    void testTaskManagerFailoverForNewlyAddedCollection() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.TM,
@@ -262,7 +253,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForNewlyAddedCollectionWithAheadOplog() throws Exception {
+    void testTaskManagerFailoverForNewlyAddedCollectionWithAheadOplog() throws Exception {
         testNewlyAddedCollectionOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.TM,
@@ -273,7 +264,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForRemoveCollectionSingleParallelism() throws Exception {
+    void testJobManagerFailoverForRemoveCollectionSingleParallelism() throws Exception {
         testRemoveCollectionsOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.JM,
@@ -284,7 +275,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForRemoveCollection() throws Exception {
+    void testJobManagerFailoverForRemoveCollection() throws Exception {
         testRemoveCollectionsOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.JM,
@@ -295,7 +286,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForRemoveCollectionSingleParallelism() throws Exception {
+    void testTaskManagerFailoverForRemoveCollectionSingleParallelism() throws Exception {
         testRemoveCollectionsOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.TM,
@@ -306,7 +297,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForRemoveCollection() throws Exception {
+    void testTaskManagerFailoverForRemoveCollection() throws Exception {
         testRemoveCollectionsOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.TM,
@@ -317,7 +308,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testRemoveCollectionSingleParallelism() throws Exception {
+    void testRemoveCollectionSingleParallelism() throws Exception {
         testRemoveCollectionsOneByOne(
                 1,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -328,7 +319,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testRemoveCollection() throws Exception {
+    void testRemoveCollection() throws Exception {
         testRemoveCollectionsOneByOne(
                 DEFAULT_PARALLELISM,
                 MongoDBTestUtils.FailoverType.NONE,
@@ -339,7 +330,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
     }
 
     @Test
-    public void testRemoveAndAddCollectionsOneByOne() throws Exception {
+    void testRemoveAndAddCollectionsOneByOne() throws Exception {
         testRemoveAndAddCollectionsOneByOne(
                 1, "address_hangzhou", "address_beijing", "address_shanghai", "address_shenzhen");
     }
@@ -351,9 +342,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
         // step 1: create mongodb collections with all collections included
         initialAddressCollections(database, captureAddressCollections);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // get all expected data
         List<String> fetchedDataList = new ArrayList<>();
@@ -532,9 +521,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
         initialAddressCollections(
                 mongodbClient.getDatabase(customerDatabase), captureAddressCollections);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // get all expected data
         List<String> fetchedDataList = new ArrayList<>();
@@ -585,12 +572,16 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                 MongoDBTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             MongoDBTestUtils.waitForSinkSize("sink", fetchedDataList.size());
             MongoDBAssertUtils.assertEqualsInAnyOrder(
                     fetchedDataList, TestValuesTableFactory.getRawResultsAsStrings("sink"));
+            // sleep 1s to wait for the assign status to INITIAL_ASSIGNING_FINISHED.
+            // Otherwise, the restart job won't read newly added tables, and this test will be
+            // stuck.
+            Thread.sleep(1000L);
             finishedSavePointPath = triggerSavepointWithRetry(jobClient, savepointDirectory);
             jobClient.cancel().get();
         }
@@ -670,7 +661,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                 MongoDBTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
 
@@ -716,18 +707,14 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
         initialAddressCollections(
                 mongodbClient.getDatabase(customerDatabase), captureAddressCollections);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // test newly added collection one by one
         String finishedSavePointPath = null;
         List<String> fetchedDataList = new ArrayList<>();
         for (int round = 0; round < captureAddressCollections.length; round++) {
             String[] captureCollectionsThisRound =
-                    Arrays.asList(captureAddressCollections)
-                            .subList(0, round + 1)
-                            .toArray(new String[0]);
+                    Arrays.copyOf(captureAddressCollections, round + 1);
             String newlyAddedCollection = captureAddressCollections[round];
             if (makeOplogBeforeCapture) {
                 makeOplogBeforeCaptureForAddressCollection(
@@ -792,13 +779,15 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                 MongoDBTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             fetchedDataList.addAll(expectedSnapshotDataThisRound);
             waitForUpsertSinkSize("sink", fetchedDataList.size());
             MongoDBAssertUtils.assertEqualsInAnyOrder(
                     fetchedDataList, TestValuesTableFactory.getResultsAsStrings("sink"));
+            // Wait 1s until snapshot phase finished, make sure the binlog data is not lost.
+            Thread.sleep(1000L);
 
             // step 3: make some changelog data for this round
             makeFirstPartOplogForAddressCollection(
@@ -807,7 +796,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                 MongoDBTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             makeSecondPartOplogForAddressCollections(
@@ -841,7 +830,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
             waitForUpsertSinkSize("sink", fetchedDataList.size());
             // the result size of sink may arrive fetchedDataList.size() with old data, wait one
             // checkpoint to wait retract old record and send new record
-            Thread.sleep(1000);
+            Thread.sleep(1000L);
             MongoDBAssertUtils.assertEqualsInAnyOrder(
                     fetchedDataList, TestValuesTableFactory.getResultsAsStrings("sink"));
 
@@ -859,7 +848,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
             // make initial data for given collection.
             String cityName = collectionName.split("_")[1];
             // B - enable collection-level fulldoc pre & post image for change capture collection
-            mongoContainer.executeCommandInDatabase(
+            MONGO_CONTAINER.executeCommandInDatabase(
                     String.format(
                             "db.createCollection('%s'); db.runCommand({ collMod: '%s', changeStreamPreAndPostImages: { enabled: true } })",
                             collectionName, collectionName),
@@ -996,7 +985,7 @@ public class NewlyAddedTableITCase extends MongoDBSourceTestBase {
                         + " 'scan.newly-added-table.enabled' = 'true'"
                         + " %s"
                         + ")",
-                mongoContainer.getHostAndPort(),
+                MONGO_CONTAINER.getHostAndPort(),
                 FLINK_USER,
                 FLINK_USER_PASSWORD,
                 customerDatabase,
