@@ -169,7 +169,7 @@ public class PendingSplitsStateSerializer implements SimpleVersionedSerializer<P
         out.writeBoolean(hasTableIsSplitting);
         if (hasTableIsSplitting) {
             ChunkSplitterState chunkSplitterState = state.getChunkSplitterState();
-            out.writeUTF(chunkSplitterState.getCurrentSplittingTableId().toString());
+            out.writeUTF(chunkSplitterState.getCurrentSplittingTableId().toDoubleQuotedString());
             out.writeUTF(
                     SerializerUtils.rowToSerializedString(
                             new Object[] {chunkSplitterState.getNextChunkStart().getValue()}));
@@ -415,7 +415,7 @@ public class PendingSplitsStateSerializer implements SimpleVersionedSerializer<P
         final int size = tableIds.size();
         out.writeInt(size);
         for (TableId tableId : tableIds) {
-            out.writeUTF(tableId.toString());
+            out.writeUTF(tableId.toDoubleQuotedString());
         }
     }
 
