@@ -40,6 +40,7 @@ import javax.annotation.Nullable;
 
 import java.io.IOException;
 import java.util.ArrayDeque;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
@@ -102,7 +103,7 @@ public class MySqlSplitReader implements SplitReader<SourceRecords, MySqlSplit>
         Iterator<SourceRecords> dataIt;
         if (currentReader == null) {
             // (1) Reads binlog split firstly and then read snapshot split
-            if (binlogSplits.size() > 0) {
+            if (!binlogSplits.isEmpty()) {
                 // the binlog split may come from:
                 // (a) the initial binlog split
                 // (b) added back binlog-split in newly added table process
@@ -110,7 +111,7 @@ public class MySqlSplitReader implements SplitReader<SourceRecords, MySqlSplit>
                 currentSplitId = nextSplit.splitId();
                 currentReader = getBinlogSplitReader();
                 currentReader.submitSplit(nextSplit);
-            } else if (snapshotSplits.size() > 0) {
+            } else if (!snapshotSplits.isEmpty()) {
                 MySqlSplit nextSplit = snapshotSplits.poll();
                 currentSplitId = nextSplit.splitId();
                 currentReader = getSnapshotSplitReader();
@@ -119,19 +120,21 @@ public class MySqlSplitReader implements SplitReader<SourceRecords, MySqlSplit>
                 LOG.info("No available split to read.");
             }
             dataIt = currentReader.pollSplitRecords();
-            return dataIt == null ? finishedSplit() : forRecords(dataIt);
+            return dataIt == null ? finishedSplit(true) : forUnfinishedRecords(dataIt);
         } else if (currentReader instanceof SnapshotSplitReader) {
-            // (2) try to switch to binlog split reading util current snapshot split finished
             dataIt = currentReader.pollSplitRecords();
             if (dataIt != null) {
                 // first fetch data of snapshot split, return and emit the records of snapshot split
-                MySqlRecords records;
+                return forUnfinishedRecords(dataIt);
+            } else {
+                // (2) try to switch to binlog split reading util current snapshot split finished
+                MySqlRecords finishedRecords;
                 if (context.isHasAssignedBinlogSplit()) {
-                    records = forNewAddedTableFinishedSplit(currentSplitId, dataIt);
+                    finishedRecords = forNewAddedTableFinishedSplit(currentSplitId);
                     closeSnapshotReader();
                     closeBinlogReader();
                 } else {
-                    records = forRecords(dataIt);
+                    finishedRecords = finishedSplit(false);
                     MySqlSplit nextSplit = snapshotSplits.poll();
                     if (nextSplit != null) {
                         currentSplitId = nextSplit.splitId();
@@ -140,9 +143,7 @@ public class MySqlSplitReader implements SplitReader<SourceRecords, MySqlSplit>
                         closeSnapshotReader();
                     }
                 }
-                return records;
-            } else {
-                return finishedSplit();
+                return finishedRecords;
             }
         } else if (currentReader instanceof BinlogSplitReader) {
             // (3) switch to snapshot split reading if there are newly added snapshot splits
@@ -157,46 +158,41 @@ public class MySqlSplitReader implements SplitReader<SourceRecords, MySqlSplit>
                     currentReader = getSnapshotSplitReader();
                     currentReader.submitSplit(nextSplit);
                 }
-                return MySqlRecords.forBinlogRecords(BINLOG_SPLIT_ID, dataIt);
+                return MySqlRecords.forUnfinishedRecords(BINLOG_SPLIT_ID, dataIt);
             } else {
                 // null will be returned after receiving suspend binlog event
                 // finish current binlog split reading
                 closeBinlogReader();
-                return finishedSplit();
+                return finishedSplit(true);
             }
         } else {
             throw new IllegalStateException("Unsupported reader type.");
         }
     }
 
-    private MySqlRecords finishedSplit() {
+    private MySqlRecords finishedSplit(boolean recycleScanFetcher) {
         final MySqlRecords finishedRecords = MySqlRecords.forFinishedSplit(currentSplitId);
+        if (recycleScanFetcher) {
+            closeSnapshotReader();
+        }
         currentSplitId = null;
         return finishedRecords;
     }
 
-    private MySqlRecords forRecords(Iterator<SourceRecords> dataIt) {
-        if (currentReader instanceof SnapshotSplitReader) {
-            final MySqlRecords finishedRecords =
-                    MySqlRecords.forSnapshotRecords(currentSplitId, dataIt);
-            closeSnapshotReader();
-            return finishedRecords;
-        } else {
-            return MySqlRecords.forBinlogRecords(currentSplitId, dataIt);
-        }
+    private MySqlRecords forUnfinishedRecords(Iterator<SourceRecords> dataIt) {
+        return MySqlRecords.forUnfinishedRecords(currentSplitId, dataIt);
     }
 
     /**
      * Finishes new added snapshot split, mark the binlog split as finished too, we will add the
      * binlog split back in {@code MySqlSourceReader}.
      */
-    private MySqlRecords forNewAddedTableFinishedSplit(
-            final String splitId, final Iterator<SourceRecords> recordsForSplit) {
+    private MySqlRecords forNewAddedTableFinishedSplit(final String splitId) {
         final Set<String> finishedSplits = new HashSet<>();
         finishedSplits.add(splitId);
         finishedSplits.add(BINLOG_SPLIT_ID);
         currentSplitId = null;
-        return new MySqlRecords(splitId, recordsForSplit, finishedSplits);
+        return new MySqlRecords(splitId, Collections.emptyIterator(), finishedSplits);
     }
 
     @Override
