@@ -100,6 +100,9 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
     final boolean skipSnapshotBackFill;
     final boolean parseOnlineSchemaChanges;
     private final boolean useLegacyJsonFormat;
+    private final boolean assignUnboundedChunkFirst;
+
+    private final boolean appendOnly;
 
     // --------------------------------------------------------------------------------------------
     // Mutable attributes
@@ -139,7 +142,9 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
             @Nullable String chunkKeyColumn,
             boolean skipSnapshotBackFill,
             boolean parseOnlineSchemaChanges,
-            boolean useLegacyJsonFormat) {
+            boolean useLegacyJsonFormat,
+            boolean assignUnboundedChunkFirst,
+            boolean appendOnly) {
         this.physicalSchema = physicalSchema;
         this.port = port;
         this.hostname = checkNotNull(hostname);
@@ -171,11 +176,17 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
         this.chunkKeyColumn = chunkKeyColumn;
         this.skipSnapshotBackFill = skipSnapshotBackFill;
         this.useLegacyJsonFormat = useLegacyJsonFormat;
+        this.assignUnboundedChunkFirst = assignUnboundedChunkFirst;
+        this.appendOnly = appendOnly;
     }
 
     @Override
     public ChangelogMode getChangelogMode() {
-        return ChangelogMode.all();
+        if (appendOnly) {
+            return ChangelogMode.insertOnly();
+        } else {
+            return ChangelogMode.all();
+        }
     }
 
     @Override
@@ -194,6 +205,7 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
                         .setServerTimeZone(serverTimeZone)
                         .setUserDefinedConverterFactory(
                                 MySqlDeserializationConverterFactory.instance())
+                        .setAppendOnly(appendOnly)
                         .build();
         if (enableParallelRead) {
             MySqlSource<RowData> parallelSource =
@@ -228,6 +240,7 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
                             .skipSnapshotBackfill(skipSnapshotBackFill)
                             .parseOnLineSchemaChanges(parseOnlineSchemaChanges)
                             .useLegacyJsonFormat(useLegacyJsonFormat)
+                            .assignUnboundedChunkFirst(assignUnboundedChunkFirst)
                             .build();
             return SourceProvider.of(parallelSource);
         } else {
@@ -315,7 +328,9 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
                         chunkKeyColumn,
                         skipSnapshotBackFill,
                         parseOnlineSchemaChanges,
-                        useLegacyJsonFormat);
+                        useLegacyJsonFormat,
+                        assignUnboundedChunkFirst,
+                        appendOnly);
         source.metadataKeys = metadataKeys;
         source.producedDataType = producedDataType;
         return source;
@@ -357,7 +372,11 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
                 && Objects.equals(jdbcProperties, that.jdbcProperties)
                 && Objects.equals(heartbeatInterval, that.heartbeatInterval)
                 && Objects.equals(chunkKeyColumn, that.chunkKeyColumn)
-                && Objects.equals(skipSnapshotBackFill, that.skipSnapshotBackFill);
+                && Objects.equals(skipSnapshotBackFill, that.skipSnapshotBackFill)
+                && parseOnlineSchemaChanges == that.parseOnlineSchemaChanges
+                && useLegacyJsonFormat == that.useLegacyJsonFormat
+                && assignUnboundedChunkFirst == that.assignUnboundedChunkFirst
+                && Objects.equals(appendOnly, that.appendOnly);
     }
 
     @Override
@@ -390,7 +409,11 @@ public class MySqlTableSource implements ScanTableSource, SupportsReadingMetadat
                 jdbcProperties,
                 heartbeatInterval,
                 chunkKeyColumn,
-                skipSnapshotBackFill);
+                skipSnapshotBackFill,
+                parseOnlineSchemaChanges,
+                useLegacyJsonFormat,
+                assignUnboundedChunkFirst,
+                appendOnly);
     }
 
     @Override
