@@ -34,6 +34,7 @@ import org.apache.flink.cdc.connectors.mysql.source.split.MySqlSplit;
 import org.apache.flink.cdc.connectors.mysql.source.split.SourceRecords;
 import org.apache.flink.cdc.connectors.mysql.source.utils.RecordUtils;
 import org.apache.flink.cdc.connectors.mysql.source.utils.TableDiscoveryUtils;
+import org.apache.flink.cdc.connectors.mysql.source.utils.hooks.SnapshotPhaseHooks;
 import org.apache.flink.cdc.connectors.mysql.table.StartupOptions;
 import org.apache.flink.cdc.connectors.mysql.testutils.MySqlContainer;
 import org.apache.flink.cdc.connectors.mysql.testutils.MySqlVersion;
@@ -60,6 +61,7 @@ import io.debezium.relational.history.TableChanges.TableChange;
 import org.apache.kafka.connect.data.Struct;
 import org.apache.kafka.connect.source.SourceRecord;
 import org.assertj.core.api.Assertions;
+import org.jetbrains.annotations.NotNull;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
@@ -88,6 +90,7 @@ import static org.apache.flink.cdc.connectors.mysql.source.utils.RecordUtils.get
 import static org.apache.flink.cdc.connectors.mysql.source.utils.RecordUtils.getStartingOffsetOfBinlogSplit;
 import static org.apache.flink.cdc.connectors.mysql.testutils.MetricsUtils.getMySqlSplitEnumeratorContext;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for {@link org.apache.flink.cdc.connectors.mysql.debezium.reader.BinlogSplitReader}. */
 class BinlogSplitReaderTest extends MySqlSourceTestBase {
@@ -116,6 +119,9 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
         LOG.info("Starting MySql8 containers...");
         Startables.deepStart(Stream.of(MYSQL8_CONTAINER)).join();
         LOG.info("Container MySql8 is started.");
+        LOG.info("Starting MySqlNoGtid containers...");
+        Startables.deepStart(Stream.of(MYSQL_CONTAINER_NOGTID)).join();
+        LOG.info("Container MySqlNoGtid is started.");
     }
 
     @AfterAll
@@ -123,6 +129,9 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
         LOG.info("Stopping MySql8 containers...");
         MYSQL8_CONTAINER.stop();
         LOG.info("Container MySql8 is stopped.");
+        LOG.info("Stopping MySqlNoGtid containers...");
+        MYSQL_CONTAINER_NOGTID.stop();
+        LOG.info("Container MySqlNoGtid is stopped.");
     }
 
     @AfterEach
@@ -175,6 +184,118 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
         assertEqualsInAnyOrder(Arrays.asList(expected), actual);
     }
 
+    @Test
+    void testSnapshotScanSkipBackfillWithPostHighWatermark() throws Exception {
+        String tableName = "customers_even_dist";
+        testSnapshotScanSkipBackfill(
+                getSnapshotPhaseHooksWithPostHighWatermark(tableName), tableName);
+    }
+
+    @Test
+    void testSnapshotScanSkipBackfillWithPreHighWatermark() throws Exception {
+        String tableName = "customers_even_dist";
+        testSnapshotScanSkipBackfill(
+                getSnapshotPhaseHooksWithPreHighWatermark(tableName), tableName);
+    }
+
+    void testSnapshotScanSkipBackfill(SnapshotPhaseHooks snapshotHooks, String tableName)
+            throws Exception {
+        customerDatabase.createAndInitialize();
+        MySqlSourceConfig sourceConfig = getConfig(new String[] {tableName}, true);
+        binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
+        mySqlConnection = DebeziumUtils.createMySqlConnection(sourceConfig);
+
+        final DataType dataType =
+                DataTypes.ROW(
+                        DataTypes.FIELD("id", DataTypes.BIGINT()),
+                        DataTypes.FIELD("name", DataTypes.STRING()),
+                        DataTypes.FIELD("address", DataTypes.STRING()),
+                        DataTypes.FIELD("phone_number", DataTypes.STRING()));
+        List<MySqlSnapshotSplit> splits = getMySqlSplits(new String[] {tableName}, sourceConfig);
+        String[] expected =
+                new String[] {
+                    "+I[101, user_1, Shanghai, 123567891234]",
+                    "+I[102, user_2, Shanghai, 123567891234]",
+                    "+I[103, user_3, Shanghai, 123567891234]",
+                    "+I[104, user_4, Shanghai, 123567891234]",
+                    "+I[105, user_5, Shanghai, 123567891234]",
+                    "+I[106, user_6, Shanghai, 123567891234]",
+                    "+I[107, user_7, Shanghai, 123567891234]",
+                    "+I[108, user_8, Shanghai, 123567891234]",
+                    "-U[103, user_3, Shanghai, 123567891234]",
+                    "+U[103, user_3, Hangzhou, 123567891234]",
+                    "-D[102, user_2, Shanghai, 123567891234]",
+                    "+I[102, user_2, Hangzhou, 123567891234]",
+                    "-U[103, user_3, Hangzhou, 123567891234]",
+                    "+U[103, user_3, Shanghai, 123567891234]",
+                    "-U[103, user_3, Shanghai, 123567891234]",
+                    "+U[103, user_3, Hangzhou, 123567891234]",
+                    "-D[102, user_2, Hangzhou, 123567891234]",
+                    "+I[102, user_2, Shanghai, 123567891234]",
+                    "-U[103, user_3, Hangzhou, 123567891234]",
+                    "+U[103, user_3, Shanghai, 123567891234]",
+                    "+I[2001, user_22, Shanghai, 123567891234]",
+                    "+I[2002, user_23, Shanghai, 123567891234]",
+                    "+I[2003, user_24, Shanghai, 123567891234]"
+                };
+
+        // skip snapshot backfill makes highwatermark equal lowwatermark, so need 2 splits to
+        List<String> actual =
+                readBinlogSplitsFromSnapshotSplits(
+                        splits,
+                        dataType,
+                        sourceConfig,
+                        2,
+                        23,
+                        splits.get(splits.size() - 1).getTableId(),
+                        snapshotHooks);
+        assertEqualsInAnyOrder(Arrays.asList(expected), actual);
+    }
+
+    @NotNull
+    private SnapshotPhaseHooks getSnapshotPhaseHooksWithPreHighWatermark(String tableName) {
+        String tableId = customerDatabase.getDatabaseName() + "." + tableName;
+        String[] changingDataSql =
+                new String[] {
+                    "UPDATE " + tableId + " SET address = 'Hangzhou' where id = 103",
+                    "DELETE FROM " + tableId + " where id = 102",
+                    "INSERT INTO " + tableId + " VALUES(102, 'user_2','Hangzhou','123567891234')",
+                    "UPDATE " + tableId + " SET address = 'Shanghai' where id = 103",
+                };
+
+        SnapshotPhaseHooks snapshotHooks = new SnapshotPhaseHooks();
+        snapshotHooks.setPostHighWatermarkAction(
+                (mySqlConnection, split) -> {
+                    if (split.splitId().equals(tableId + ":0")) {
+                        mySqlConnection.execute(changingDataSql);
+                        mySqlConnection.commit();
+                    }
+                });
+        return snapshotHooks;
+    }
+
+    @NotNull
+    private SnapshotPhaseHooks getSnapshotPhaseHooksWithPostHighWatermark(String tableName) {
+        String tableId = customerDatabase.getDatabaseName() + "." + tableName;
+        String[] changingDataSql =
+                new String[] {
+                    "UPDATE " + tableId + " SET address = 'Hangzhou' where id = 103",
+                    "DELETE FROM " + tableId + " where id = 102",
+                    "INSERT INTO " + tableId + " VALUES(102, 'user_2','Hangzhou','123567891234')",
+                    "UPDATE " + tableId + " SET address = 'Shanghai' where id = 103",
+                };
+
+        SnapshotPhaseHooks snapshotHooks = new SnapshotPhaseHooks();
+        snapshotHooks.setPostHighWatermarkAction(
+                (mySqlConnection, split) -> {
+                    if (split.splitId().equals(tableId + ":0")) {
+                        mySqlConnection.execute(changingDataSql);
+                        mySqlConnection.commit();
+                    }
+                });
+        return snapshotHooks;
+    }
+
     @Test
     void testReadAllBinlogSplitsForOneTable() throws Exception {
         customerDatabase.createAndInitialize();
@@ -358,6 +479,53 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
         reader.close();
     }
 
+    @Test
+    void testReadBinlogWithoutGtidFromLatestOffset() throws Exception {
+        customerDatabaseNoGtid.createAndInitialize();
+        MySqlSourceConfig sourceConfig =
+                getConfig(
+                        MYSQL_CONTAINER_NOGTID,
+                        customerDatabaseNoGtid,
+                        StartupOptions.latest(),
+                        new String[] {"customers"});
+        binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
+        mySqlConnection = DebeziumUtils.createMySqlConnection(sourceConfig);
+
+        // Create reader and submit splits
+        MySqlBinlogSplit split = createBinlogSplit(sourceConfig);
+        BinlogSplitReader reader = createBinlogReader(sourceConfig);
+        reader.submitSplit(split);
+
+        // Create some binlog events
+        makeCustomersBinlogEvents(
+                mySqlConnection, customerDatabaseNoGtid.qualifiedTableName("customers"), false);
+
+        final DataType dataType =
+                DataTypes.ROW(
+                        DataTypes.FIELD("id", DataTypes.BIGINT()),
+                        DataTypes.FIELD("name", DataTypes.STRING()),
+                        DataTypes.FIELD("address", DataTypes.STRING()),
+                        DataTypes.FIELD("phone_number", DataTypes.STRING()));
+        String[] expected =
+                new String[] {
+                    "-U[103, user_3, Shanghai, 123567891234]",
+                    "+U[103, user_3, Hangzhou, 123567891234]",
+                    "-D[102, user_2, Shanghai, 123567891234]",
+                    "+I[102, user_2, Shanghai, 123567891234]",
+                    "-U[103, user_3, Hangzhou, 123567891234]",
+                    "+U[103, user_3, Shanghai, 123567891234]",
+                    "-U[1010, user_11, Shanghai, 123567891234]",
+                    "+U[1010, Hangzhou, Shanghai, 123567891234]",
+                    "+I[2001, user_22, Shanghai, 123567891234]",
+                    "+I[2002, user_23, Shanghai, 123567891234]",
+                    "+I[2003, user_24, Shanghai, 123567891234]"
+                };
+        List<String> actual = readBinlogSplits(dataType, reader, expected.length);
+        assertEqualsInOrder(Arrays.asList(expected), actual);
+
+        reader.close();
+    }
+
     @Test
     void testReadBinlogFromEarliestOffset() throws Exception {
         customerDatabase.createAndInitialize();
@@ -751,7 +919,11 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
 
         // Create config and initializer client and connections
         MySqlSourceConfig sourceConfig =
-                getConfigFactory(MYSQL_CONTAINER, customerDatabase, new String[] {"customers"})
+                getConfigFactory(
+                                MYSQL_CONTAINER,
+                                customerDatabase,
+                                new String[] {"customers"},
+                                false)
                         .startupOptions(StartupOptions.latest())
                         .heartbeatInterval(heartbeatInterval)
                         .debeziumProperties(dbzProps)
@@ -889,7 +1061,6 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
 
     @Test
     public void testBinlogOffsetCompareWithSnapshotAndBinlogPhase() throws Exception {
-        Startables.deepStart(Stream.of(MYSQL_CONTAINER_NOGTID)).join();
         // Preparations
         customerDatabaseNoGtid.createAndInitialize();
         MySqlSourceConfig sourceConfig =
@@ -946,10 +1117,40 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
 
         List<SourceRecord> sourceRecords =
                 pollRecordsFromReader(binlogReader, RecordUtils::isDataChangeRecord);
-        MYSQL_CONTAINER_NOGTID.stop();
         Assertions.assertThat(sourceRecords).isEmpty();
     }
 
+    @Test
+    void testReadBinlogWithException() throws Exception {
+        customerDatabase.createAndInitialize();
+        MySqlSourceConfig sourceConfig =
+                getConfig(StartupOptions.latest(), new String[] {"customers"});
+        binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
+        mySqlConnection = DebeziumUtils.createMySqlConnection(sourceConfig);
+
+        // Create reader and submit splits
+        StatefulTaskContext statefulTaskContext =
+                new StatefulTaskContext(sourceConfig, binaryLogClient, mySqlConnection);
+        MySqlBinlogSplit split = createBinlogSplit(sourceConfig);
+        BinlogSplitReader reader = new BinlogSplitReader(statefulTaskContext, 0);
+
+        // Mock an exception occurring during stream split reading by setting the error handler
+        // and stopping the change event source to test exception handling
+        reader.submitSplit(split);
+        statefulTaskContext
+                .getErrorHandler()
+                .setProducerThrowable(new RuntimeException("Test read with exception"));
+        reader.getChangeEventSourceContext().stopChangeEventSource();
+        // wait until executor is finished.
+        Thread.sleep(500L);
+
+        assertThatThrownBy(() -> pollRecordsFromReader(reader, RecordUtils::isDataChangeRecord))
+                .rootCause()
+                .isExactlyInstanceOf(RuntimeException.class)
+                .hasMessage("Test read with exception");
+        reader.close();
+    }
+
     private BinlogSplitReader createBinlogReader(MySqlSourceConfig sourceConfig) {
         return createBinlogReader(sourceConfig, false);
     }
@@ -1048,10 +1249,29 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
             int expectedSize,
             TableId binlogChangeTableId)
             throws Exception {
+        return readBinlogSplitsFromSnapshotSplits(
+                sqlSplits,
+                dataType,
+                sourceConfig,
+                scanSplitsNum,
+                expectedSize,
+                binlogChangeTableId,
+                SnapshotPhaseHooks.empty());
+    }
+
+    private List<String> readBinlogSplitsFromSnapshotSplits(
+            List<MySqlSnapshotSplit> sqlSplits,
+            DataType dataType,
+            MySqlSourceConfig sourceConfig,
+            int scanSplitsNum,
+            int expectedSize,
+            TableId binlogChangeTableId,
+            SnapshotPhaseHooks snapshotHooks)
+            throws Exception {
         final StatefulTaskContext statefulTaskContext =
                 new StatefulTaskContext(sourceConfig, binaryLogClient, mySqlConnection);
         final SnapshotSplitReader snapshotSplitReader =
-                new SnapshotSplitReader(statefulTaskContext, 0);
+                new SnapshotSplitReader(statefulTaskContext, 0, snapshotHooks);
 
         // step-1: read snapshot splits firstly
         List<SourceRecord> snapshotRecords = new ArrayList<>();
@@ -1298,22 +1518,31 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
             UniqueDatabase database,
             StartupOptions startupOptions,
             String[] captureTables) {
-        return getConfigFactory(container, database, captureTables)
+        return getConfigFactory(container, database, captureTables, false)
                 .startupOptions(startupOptions)
                 .createConfig(0);
     }
 
     private MySqlSourceConfig getConfig(String[] captureTables) {
-        return getConfig(MYSQL_CONTAINER, customerDatabase, captureTables);
+        return getConfig(captureTables, false);
+    }
+
+    private MySqlSourceConfig getConfig(String[] captureTables, boolean skipSnapshotBackfill) {
+        return getConfigFactory(
+                        MYSQL_CONTAINER, customerDatabase, captureTables, skipSnapshotBackfill)
+                .createConfig(0);
     }
 
     private MySqlSourceConfig getConfig(
             MySqlContainer container, UniqueDatabase database, String[] captureTables) {
-        return getConfigFactory(container, database, captureTables).createConfig(0);
+        return getConfigFactory(container, database, captureTables, false).createConfig(0);
     }
 
     private MySqlSourceConfigFactory getConfigFactory(
-            MySqlContainer container, UniqueDatabase database, String[] captureTables) {
+            MySqlContainer container,
+            UniqueDatabase database,
+            String[] captureTables,
+            boolean skipSnapshotBackfill) {
         String[] captureTableIds =
                 Arrays.stream(captureTables)
                         .map(tableName -> database.getDatabaseName() + "." + tableName)
@@ -1327,6 +1556,7 @@ class BinlogSplitReaderTest extends MySqlSourceTestBase {
                 .username(database.getUsername())
                 .splitSize(4)
                 .fetchSize(2)
+                .skipSnapshotBackfill(skipSnapshotBackfill)
                 .password(database.getPassword());
     }
 
