@@ -17,16 +17,15 @@
 
 package org.apache.flink.cdc.connectors.polardbx;
 
+import org.apache.flink.cdc.common.utils.TestCaseUtils;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 import org.apache.flink.test.util.AbstractTestBase;
 import org.apache.flink.types.Row;
 
-import com.github.dockerjava.api.model.ExposedPort;
-import com.github.dockerjava.api.model.PortBinding;
-import com.github.dockerjava.api.model.Ports;
 import org.apache.commons.lang3.StringUtils;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.containers.GenericContainer;
@@ -39,6 +38,7 @@ import java.nio.file.Files;
 import java.nio.file.Paths;
 import java.sql.Connection;
 import java.sql.DriverManager;
+import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.time.Duration;
@@ -55,56 +55,54 @@ import java.util.stream.Stream;
 
 import static java.lang.String.format;
 import static org.apache.flink.util.Preconditions.checkState;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
 
 /** Basic class for testing Database Polardbx which supported the mysql protocol. */
 public abstract class PolardbxSourceTestBase extends AbstractTestBase {
     private static final Logger LOG = LoggerFactory.getLogger(PolardbxSourceTestBase.class);
     private static final Pattern COMMENT_PATTERN = Pattern.compile("^(.*)--.*$");
-    protected static final Integer PORT = 8527;
-    protected static final String HOST_NAME = "127.0.0.1";
-    protected static final String USER_NAME = "polardbx_root";
-    protected static final String PASSWORD = "123456";
+
     private static final String IMAGE_VERSION = "2.1.0";
     private static final DockerImageName POLARDBX_IMAGE =
             DockerImageName.parse("polardbx/polardb-x:" + IMAGE_VERSION);
 
+    protected static final Integer INNER_PORT = 8527;
+    protected static final String USER_NAME = "polardbx_root";
+    protected static final String PASSWORD = "123456";
+    protected static final Duration WAITING_TIMEOUT = Duration.ofMinutes(1);
+
     protected static final GenericContainer POLARDBX_CONTAINER =
             new GenericContainer<>(POLARDBX_IMAGE)
-                    .withExposedPorts(PORT)
+                    .withExposedPorts(INNER_PORT)
                     .withLogConsumer(new Slf4jLogConsumer(LOG))
-                    .withStartupTimeout(Duration.ofMinutes(3))
-                    .withCreateContainerCmdModifier(
-                            c ->
-                                    c.withPortBindings(
-                                            new PortBinding(
-                                                    Ports.Binding.bindPort(PORT),
-                                                    new ExposedPort(PORT))));
+                    .withStartupTimeout(Duration.ofMinutes(3));
 
-    @BeforeClass
-    public static void startContainers() throws InterruptedException {
-        // no need to start container when the port 8527 is listening
-        if (!checkConnection()) {
-            LOG.info("Polardbx connection is not valid, so try to start containers...");
-            Startables.deepStart(Stream.of(POLARDBX_CONTAINER)).join();
-            LOG.info("Containers are started.");
-            // here should wait 10s that make sure the polardbx is ready
-            Thread.sleep(10 * 1000);
-        }
+    protected static String getHost() {
+        return POLARDBX_CONTAINER.getHost();
     }
 
-    @AfterClass
-    public static void stopContainers() {
+    protected static int getPort() {
+        return POLARDBX_CONTAINER.getMappedPort(INNER_PORT);
+    }
+
+    @BeforeAll
+    public static void startContainers() throws InterruptedException {
+        Startables.deepStart(Stream.of(POLARDBX_CONTAINER)).join();
+        // wait and check PolarDBx CDC node is ready
+        Thread.sleep(30_000);
+        TestCaseUtils.repeatedCheck(
+                PolardbxSourceTestBase::checkConnection, WAITING_TIMEOUT, Duration.ofSeconds(20));
+        LOG.info("Containers are started.");
+    }
+
+    @AfterAll
+    static void stopContainers() {
         LOG.info("Stopping Polardbx containers...");
         POLARDBX_CONTAINER.stop();
         LOG.info("Polardbx containers are stopped.");
     }
 
     protected static String getJdbcUrl() {
-        return String.format("jdbc:mysql://%s:%s", HOST_NAME, PORT);
+        return String.format("jdbc:mysql://%s:%s", getHost(), getPort());
     }
 
     protected static Connection getJdbcConnection() throws SQLException {
@@ -114,14 +112,35 @@ public abstract class PolardbxSourceTestBase extends AbstractTestBase {
     }
 
     protected static Boolean checkConnection() {
-        LOG.info("check polardbx connection validation...");
-        try {
-            Connection connection = getJdbcConnection();
-            return connection.isValid(3);
+        LOG.info("check PolarDBx CDC node status...");
+        boolean cdcReady = false;
+        try (Connection connection = getJdbcConnection();
+                Statement statement = connection.createStatement()) {
+            ResultSet rs = statement.executeQuery("SHOW MASTER STATUS");
+            if (rs.next()) {
+                String binlogFilename = rs.getString(1);
+                long binlogPosition = rs.getLong(2);
+                // the initial binlog position is 4
+                cdcReady = StringUtils.isNotEmpty(binlogFilename) && binlogPosition > 4L;
+                if (cdcReady) {
+                    LOG.info(
+                            "PolarDBx CDC node is ready at offset {}:{}",
+                            binlogFilename,
+                            binlogPosition);
+                } else {
+                    LOG.warn(
+                            "PolarDBx CDC node is not ready at offset {}:{},  waiting...",
+                            binlogFilename,
+                            binlogPosition);
+                }
+            } else {
+                LOG.warn("PolarDBx CDC node is not ready, waiting...");
+            }
         } catch (SQLException e) {
-            LOG.warn("polardbx connection is not valid... caused by:" + e.getMessage());
-            return false;
+            cdcReady = false;
+            LOG.warn("PolarDBx CDC node is not ready... caused by:{}", e.getMessage());
         }
+        return cdcReady;
     }
 
     /** initialize database and tables with ${databaseName}.sql for testing. */
@@ -129,7 +148,7 @@ public abstract class PolardbxSourceTestBase extends AbstractTestBase {
             String databaseName, Function<String, Boolean> filter) throws InterruptedException {
         final String ddlFile = String.format("ddl/%s.sql", databaseName);
         final URL ddlTestFile = PolardbxSourceTestBase.class.getClassLoader().getResource(ddlFile);
-        assertNotNull("Cannot locate " + ddlFile, ddlTestFile);
+        Assertions.assertThat(ddlTestFile).withFailMessage("Cannot locate " + ddlFile).isNotNull();
         // need to sleep 1s, make sure the jdbc connection can be created
         Thread.sleep(1000);
         try (Connection connection = getJdbcConnection();
@@ -155,8 +174,8 @@ public abstract class PolardbxSourceTestBase extends AbstractTestBase {
             for (String stmt : statements) {
                 statement.execute(stmt);
             }
-        } catch (Exception e) {
-            throw new RuntimeException(e);
+        } catch (Throwable t) {
+            throw new RuntimeException(t);
         }
     }
 
@@ -209,15 +228,10 @@ public abstract class PolardbxSourceTestBase extends AbstractTestBase {
     }
 
     protected static void assertEqualsInAnyOrder(List<String> expected, List<String> actual) {
-        assertTrue(expected != null && actual != null);
-        assertEqualsInOrder(
-                expected.stream().sorted().collect(Collectors.toList()),
-                actual.stream().sorted().collect(Collectors.toList()));
+        Assertions.assertThat(actual).containsExactlyInAnyOrderElementsOf(expected);
     }
 
     protected static void assertEqualsInOrder(List<String> expected, List<String> actual) {
-        assertTrue(expected != null && actual != null);
-        assertEquals(expected.size(), actual.size());
-        assertArrayEquals(expected.toArray(new String[0]), actual.toArray(new String[0]));
+        Assertions.assertThat(actual).containsExactlyElementsOf(expected);
     }
 }
