@@ -17,7 +17,6 @@
 
 package org.apache.flink.cdc.connectors.oceanbase;
 
-import org.apache.flink.cdc.connectors.oceanbase.testutils.LogProxyContainer;
 import org.apache.flink.cdc.connectors.oceanbase.testutils.OceanBaseContainer;
 
 import org.slf4j.Logger;
@@ -33,18 +32,10 @@ public class OceanBaseTestUtils {
     private static final Logger LOG = LoggerFactory.getLogger(OceanBaseTestUtils.class);
 
     private static final String OB_4_3_3_VERSION = "4.3.3.0-100000142024101215";
-    private static final String OB_LOG_PROXY_2_0_2_VERSION = "2.0.2-101000142024080121";
-    private static final String CDC_TEST_OB_VERSION = "4.2.1.6-106000012024042515";
 
     private static final String SYS_PASSWORD = "123456";
     private static final String TEST_PASSWORD = "654321";
 
-    public static OceanBaseContainer createOceanBaseContainerForCDC() {
-        return createOceanBaseContainer(CDC_TEST_OB_VERSION, "mini")
-                .withSysPassword(SYS_PASSWORD)
-                .withStartupTimeout(Duration.ofMinutes(4));
-    }
-
     public static OceanBaseContainer createOceanBaseContainerForJdbc() {
         return createOceanBaseContainer(OB_4_3_3_VERSION, "mini")
                 .withStartupTimeout(Duration.ofMinutes(4));
@@ -58,11 +49,4 @@ public class OceanBaseTestUtils {
                 .withEnv("OB_LOG_DISK_SIZE", "4G")
                 .withLogConsumer(new Slf4jLogConsumer(LOG));
     }
-
-    public static LogProxyContainer createLogProxyContainer() {
-        return new LogProxyContainer(OB_LOG_PROXY_2_0_2_VERSION)
-                .withSysPassword(SYS_PASSWORD)
-                .withStartupTimeout(Duration.ofMinutes(1))
-                .withLogConsumer(new Slf4jLogConsumer(LOG));
-    }
 }
