@@ -36,14 +36,12 @@ import org.apache.flink.table.catalog.UniqueConstraint;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.types.Row;
 import org.apache.flink.util.CloseableIterator;
-import org.apache.flink.util.ExceptionUtils;
 
 import io.debezium.connector.oracle.OracleConnection;
 import io.debezium.jdbc.JdbcConfiguration;
 import org.apache.commons.lang3.StringUtils;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.Timeout;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -54,6 +52,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
+import java.util.concurrent.TimeUnit;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
@@ -63,9 +62,9 @@ import static org.apache.flink.table.api.DataTypes.BIGINT;
 import static org.apache.flink.table.api.DataTypes.STRING;
 import static org.apache.flink.table.catalog.Column.physical;
 import static org.apache.flink.util.Preconditions.checkState;
-import static org.junit.Assert.assertTrue;
 
 /** IT tests for {@link OracleSourceBuilder.OracleIncrementalSource}. */
+@Timeout(value = 300, unit = TimeUnit.SECONDS)
 public class OracleSourceITCase extends OracleSourceTestBase {
     private static final int USE_POST_LOWWATERMARK_HOOK = 1;
     private static final int USE_PRE_HIGHWATERMARK_HOOK = 2;
@@ -73,59 +72,57 @@ public class OracleSourceITCase extends OracleSourceTestBase {
 
     private static final Logger LOG = LoggerFactory.getLogger(OracleSourceITCase.class);
 
-    @Rule public final Timeout timeoutPerTest = Timeout.seconds(300);
-
     @Test
-    public void testReadSingleTableWithSingleParallelism() throws Exception {
+    void testReadSingleTableWithSingleParallelism() throws Exception {
         testOracleParallelSource(
                 1, FailoverType.NONE, FailoverPhase.NEVER, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testReadSingleTableWithMultipleParallelism() throws Exception {
+    void testReadSingleTableWithMultipleParallelism() throws Exception {
         testOracleParallelSource(
                 4, FailoverType.NONE, FailoverPhase.NEVER, new String[] {"CUSTOMERS"});
     }
 
     // Failover tests
     @Test
-    public void testTaskManagerFailoverInSnapshotPhase() throws Exception {
+    void testTaskManagerFailoverInSnapshotPhase() throws Exception {
         testOracleParallelSource(
                 FailoverType.TM, FailoverPhase.SNAPSHOT, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testTaskManagerFailoverInRedoLogPhase() throws Exception {
+    void testTaskManagerFailoverInRedoLogPhase() throws Exception {
         testOracleParallelSource(
                 FailoverType.TM, FailoverPhase.REDO_LOG, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testJobManagerFailoverInSnapshotPhase() throws Exception {
+    void testJobManagerFailoverInSnapshotPhase() throws Exception {
         testOracleParallelSource(
                 FailoverType.JM, FailoverPhase.SNAPSHOT, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testJobManagerFailoverInRedoLogPhase() throws Exception {
+    void testJobManagerFailoverInRedoLogPhase() throws Exception {
         testOracleParallelSource(
                 FailoverType.JM, FailoverPhase.REDO_LOG, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testTaskManagerFailoverSingleParallelism() throws Exception {
+    void testTaskManagerFailoverSingleParallelism() throws Exception {
         testOracleParallelSource(
                 1, FailoverType.TM, FailoverPhase.SNAPSHOT, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testJobManagerFailoverSingleParallelism() throws Exception {
+    void testJobManagerFailoverSingleParallelism() throws Exception {
         testOracleParallelSource(
                 1, FailoverType.JM, FailoverPhase.SNAPSHOT, new String[] {"CUSTOMERS"});
     }
 
     @Test
-    public void testReadSingleTableWithSingleParallelismAndSkipBackfill() throws Exception {
+    void testReadSingleTableWithSingleParallelismAndSkipBackfill() throws Exception {
         testOracleParallelSource(
                 DEFAULT_PARALLELISM,
                 FailoverType.TM,
@@ -137,7 +134,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testSnapshotOnlyModeWithDMLPostHighWaterMark() throws Exception {
+    void testSnapshotOnlyModeWithDMLPostHighWaterMark() throws Exception {
         // The data num is 21, set fetchSize = 22 to test the job is bounded.
         List<String> records =
                 testBackfillWhenWritingEvents(
@@ -169,7 +166,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testSnapshotOnlyModeWithDMLPreHighWaterMark() throws Exception {
+    void testSnapshotOnlyModeWithDMLPreHighWaterMark() throws Exception {
         // The data num is 21, set fetchSize = 22 to test the job is bounded.
         List<String> records =
                 testBackfillWhenWritingEvents(
@@ -203,7 +200,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testEnableBackfillWithDMLPreHighWaterMark() throws Exception {
+    void testEnableBackfillWithDMLPreHighWaterMark() throws Exception {
 
         List<String> records =
                 testBackfillWhenWritingEvents(
@@ -238,7 +235,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testEnableBackfillWithDMLPostLowWaterMark() throws Exception {
+    void testEnableBackfillWithDMLPostLowWaterMark() throws Exception {
         List<String> records =
                 testBackfillWhenWritingEvents(
                         false, 21, USE_POST_LOWWATERMARK_HOOK, StartupOptions.initial());
@@ -272,7 +269,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testEnableBackfillWithDMLPostHighWaterMark() throws Exception {
+    void testEnableBackfillWithDMLPostHighWaterMark() throws Exception {
         List<String> records =
                 testBackfillWhenWritingEvents(
                         false, 21, USE_POST_HIGHWATERMARK_HOOK, StartupOptions.initial());
@@ -306,7 +303,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testSkipBackfillWithDMLPreHighWaterMark() throws Exception {
+    void testSkipBackfillWithDMLPreHighWaterMark() throws Exception {
         List<String> records =
                 testBackfillWhenWritingEvents(
                         true, 25, USE_PRE_HIGHWATERMARK_HOOK, StartupOptions.initial());
@@ -344,7 +341,7 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testSkipBackfillWithDMLPostLowWaterMark() throws Exception {
+    void testSkipBackfillWithDMLPostLowWaterMark() throws Exception {
 
         List<String> records =
                 testBackfillWhenWritingEvents(
@@ -384,26 +381,18 @@ public class OracleSourceITCase extends OracleSourceTestBase {
     }
 
     @Test
-    public void testTableWithChunkColumnOfNoPrimaryKey() {
+    public void testTableWithChunkColumnOfNoPrimaryKey() throws Exception {
         String chunkColumn = "NAME";
-        try {
-            testOracleParallelSource(
-                    1,
-                    FailoverType.NONE,
-                    FailoverPhase.NEVER,
-                    new String[] {"CUSTOMERS"},
-                    false,
-                    RestartStrategies.noRestart(),
-                    chunkColumn);
-        } catch (Exception e) {
-            assertTrue(
-                    ExceptionUtils.findThrowableWithMessage(
-                                    e,
-                                    String.format(
-                                            "Chunk key column '%s' doesn't exist in the primary key [%s] of the table %s.",
-                                            chunkColumn, "ID", "customer.DEBEZIUM.CUSTOMERS"))
-                            .isPresent());
-        }
+        testOracleParallelSource(
+                1,
+                FailoverType.NONE,
+                FailoverPhase.NEVER,
+                new String[] {"CUSTOMERS"},
+                false,
+                RestartStrategies.noRestart(),
+                chunkColumn);
+
+        // since `scan.incremental.snapshot.chunk.key-column` is set, an exception should not occur.
     }
 
     private List<String> testBackfillWhenWritingEvents(
@@ -612,7 +601,10 @@ public class OracleSourceITCase extends OracleSourceTestBase {
         // trigger failover after some snapshot splits read finished
         if (failoverPhase == FailoverPhase.SNAPSHOT && iterator.hasNext()) {
             triggerFailover(
-                    failoverType, jobId, miniClusterResource.getMiniCluster(), () -> sleepMs(100));
+                    failoverType,
+                    jobId,
+                    miniClusterResource.get().getMiniCluster(),
+                    () -> sleepMs(100));
         }
 
         LOG.info("snapshot data start");
@@ -625,7 +617,10 @@ public class OracleSourceITCase extends OracleSourceTestBase {
         }
         if (failoverPhase == FailoverPhase.REDO_LOG) {
             triggerFailover(
-                    failoverType, jobId, miniClusterResource.getMiniCluster(), () -> sleepMs(200));
+                    failoverType,
+                    jobId,
+                    miniClusterResource.get().getMiniCluster(),
+                    () -> sleepMs(200));
         }
         for (String tableId : captureCustomerTables) {
             makeSecondPartRedoLogEvents(ORACLE_SCHEMA + '.' + tableId);
