@@ -136,6 +136,16 @@ public class PostgresSourceBuilder<T> {
         return this;
     }
 
+    /**
+     * The session time zone in database server, e.g. "America/Los_Angeles". It controls how the
+     * TIMESTAMP type in MYSQL converted to STRING. See more
+     * https://debezium.io/documentation/reference/1.9/connectors/mysql.html#mysql-temporal-types
+     */
+    public PostgresSourceBuilder<T> serverTimeZone(String timeZone) {
+        this.configFactory.serverTimeZone(timeZone);
+        return this;
+    }
+
     /**
      * The split size (number of rows) of table snapshot, captured tables are split into multiple
      * splits when read the snapshot of table.
@@ -289,6 +299,12 @@ public class PostgresSourceBuilder<T> {
         return this;
     }
 
+    /** Whether the connector should read partitioned tables via partition root or not. */
+    public PostgresSourceBuilder<T> includePartitionedTables(boolean includePartitionedTables) {
+        this.configFactory.setIncludePartitionedTables(includePartitionedTables);
+        return this;
+    }
+
     /**
      * Build the {@link PostgresIncrementalSource}.
      *
@@ -301,6 +317,10 @@ public class PostgresSourceBuilder<T> {
                 configFactory, checkNotNull(deserializer), offsetFactory, dialect);
     }
 
+    public PostgresSourceConfigFactory getConfigFactory() {
+        return configFactory;
+    }
+
     /** The Postgres source based on the incremental snapshot framework. */
     @Experimental
     public static class PostgresIncrementalSource<T> extends JdbcIncrementalSource<T> {
