@@ -40,8 +40,7 @@ public class PostgresSourceOptions extends JdbcSourceOptions {
                     .defaultValue("decoderbufs")
                     .withDescription(
                             "The name of the Postgres logical decoding plug-in installed on the server.\n"
-                                    + "Supported values are decoderbufs, wal2json, wal2json_rds, wal2json_streaming,\n"
-                                    + "wal2json_rds_streaming and pgoutput.");
+                                    + "Supported values are decoderbufs and pgoutput.");
 
     public static final ConfigOption<String> SLOT_NAME =
             ConfigOptions.key("slot.name")
@@ -88,4 +87,14 @@ public class PostgresSourceOptions extends JdbcSourceOptions {
                                     + "By setting this to higher value, the offset that is consumed by global slot will be "
                                     + "committed after multiple checkpoint delays instead of after each checkpoint completion.\n"
                                     + "This allows continuous recycle of log files in stream phase.");
+
+    public static final ConfigOption<Boolean> SCAN_INCLUDE_PARTITIONED_TABLES_ENABLED =
+            ConfigOptions.key("scan.include-partitioned-tables.enabled")
+                    .booleanType()
+                    .defaultValue(Boolean.FALSE)
+                    .withDescription(
+                            "Enable reading from partitioned table via partition root.\n"
+                                    + "If enabled:\n"
+                                    + "(1) PUBLICATION must be created beforehand with parameter publish_via_partition_root=true\n"
+                                    + "(2) Table list (regex or predefined list) should only match the parent table name, if table list matches both parent and child tables, snapshot data will be read twice.");
 }
