@@ -86,6 +86,8 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
     private final boolean scanNewlyAddedTableEnabled;
     private final int lsnCommitCheckpointsDelay;
     private final boolean assignUnboundedChunkFirst;
+    private final boolean appendOnly;
+    private final boolean includePartitionedTables;
 
     // --------------------------------------------------------------------------------------------
     // Mutable attributes
@@ -126,7 +128,9 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
             boolean skipSnapshotBackfill,
             boolean isScanNewlyAddedTableEnabled,
             int lsnCommitCheckpointsDelay,
-            boolean assignUnboundedChunkFirst) {
+            boolean assignUnboundedChunkFirst,
+            boolean appendOnly,
+            boolean includePartitionedTables) {
         this.physicalSchema = physicalSchema;
         this.port = port;
         this.hostname = checkNotNull(hostname);
@@ -159,10 +163,16 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
         this.scanNewlyAddedTableEnabled = isScanNewlyAddedTableEnabled;
         this.lsnCommitCheckpointsDelay = lsnCommitCheckpointsDelay;
         this.assignUnboundedChunkFirst = assignUnboundedChunkFirst;
+        this.appendOnly = appendOnly;
+        this.includePartitionedTables = includePartitionedTables;
     }
 
     @Override
     public ChangelogMode getChangelogMode() {
+        if (appendOnly) {
+            return ChangelogMode.insertOnly();
+        }
+
         switch (changelogMode) {
             case UPSERT:
                 return org.apache.flink.table.connector.ChangelogMode.upsert();
@@ -190,6 +200,7 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
                                 PostgreSQLDeserializationConverterFactory.instance())
                         .setValueValidator(new PostgresValueValidator(schemaName, tableName))
                         .setChangelogMode(changelogMode)
+                        .setAppendOnly(appendOnly)
                         .build();
 
         if (enableParallelRead) {
@@ -222,6 +233,7 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
                             .scanNewlyAddedTableEnabled(scanNewlyAddedTableEnabled)
                             .lsnCommitCheckpointsDelay(lsnCommitCheckpointsDelay)
                             .assignUnboundedChunkFirst(assignUnboundedChunkFirst)
+                            .includePartitionedTables(includePartitionedTables)
                             .build();
             return SourceProvider.of(parallelSource);
         } else {
@@ -291,7 +303,9 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
                         skipSnapshotBackfill,
                         scanNewlyAddedTableEnabled,
                         lsnCommitCheckpointsDelay,
-                        assignUnboundedChunkFirst);
+                        assignUnboundedChunkFirst,
+                        appendOnly,
+                        includePartitionedTables);
         source.metadataKeys = metadataKeys;
         source.producedDataType = producedDataType;
         return source;
@@ -335,7 +349,9 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
                 && Objects.equals(closeIdleReaders, that.closeIdleReaders)
                 && Objects.equals(skipSnapshotBackfill, that.skipSnapshotBackfill)
                 && Objects.equals(scanNewlyAddedTableEnabled, that.scanNewlyAddedTableEnabled)
-                && Objects.equals(assignUnboundedChunkFirst, that.assignUnboundedChunkFirst);
+                && Objects.equals(assignUnboundedChunkFirst, that.assignUnboundedChunkFirst)
+                && Objects.equals(appendOnly, that.appendOnly)
+                && Objects.equals(includePartitionedTables, that.includePartitionedTables);
     }
 
     @Override
@@ -370,7 +386,9 @@ public class PostgreSQLTableSource implements ScanTableSource, SupportsReadingMe
                 closeIdleReaders,
                 skipSnapshotBackfill,
                 scanNewlyAddedTableEnabled,
-                assignUnboundedChunkFirst);
+                assignUnboundedChunkFirst,
+                appendOnly,
+                includePartitionedTables);
     }
 
     @Override
