@@ -325,7 +325,11 @@ class PostgresScanFetchTaskTest extends PostgresTestBase {
                     new PostgresSourceFetchTaskContext(sourceConfig, postgresDialect);
 
             return readTableSnapshotSplits(
-                    snapshotSplits, postgresSourceFetchTaskContext, 1, dataType, hooks);
+                    reOrderSnapshotSplits(snapshotSplits),
+                    postgresSourceFetchTaskContext,
+                    1,
+                    dataType,
+                    hooks);
         }
     }
 
@@ -398,4 +402,20 @@ class PostgresScanFetchTaskTest extends PostgresTestBase {
         snapshotSplitAssigner.close();
         return snapshotSplitList;
     }
+
+    // Due to the default enabling of scan.incremental.snapshot.unbounded-chunk-first.enabled,
+    // the split order becomes [end,null], [null,start], ... which is different from the original
+    // order.
+    // The first split in the list is actually the last unbounded split that should be at the end.
+    // This method adjusts the order to restore the original sequence: [null,start], ...,
+    // [end,null],
+    // ensuring the correctness of test cases.
+    private List<SnapshotSplit> reOrderSnapshotSplits(List<SnapshotSplit> snapshotSplits) {
+        if (snapshotSplits.size() > 1) {
+            SnapshotSplit firstSplit = snapshotSplits.get(0);
+            snapshotSplits.remove(0);
+            snapshotSplits.add(firstSplit);
+        }
+        return snapshotSplits;
+    }
 }
