@@ -33,6 +33,7 @@ import org.apache.flink.util.CloseableIterator;
 import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.RegisterExtension;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.ValueSource;
@@ -97,7 +98,6 @@ class PostgreSQLConnectorITCase extends PostgresTestBase {
     static void stopContainers() {
         LOG.info("Stopping containers...");
         POSTGIS_CONTAINER.stop();
-        POSTGIS_CONTAINER.stop();
         LOG.info("Containers are stopped.");
     }
 
@@ -232,6 +232,124 @@ class PostgreSQLConnectorITCase extends PostgresTestBase {
         result.getJobClient().get().cancel().get();
     }
 
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testConsumingAllEventsForPartitionedTable(boolean parallelismSnapshot)
+            throws SQLException, ExecutionException, InterruptedException {
+        setup(parallelismSnapshot);
+        initializePostgresTable(POSTGRES_CONTAINER, "inventory_partitioned");
+        String publicationName = "dbz_publication_" + new Random().nextInt(1000);
+        String slotName = getSlotName();
+        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+                Statement statement = connection.createStatement()) {
+            statement.execute(
+                    String.format(
+                            "CREATE PUBLICATION %s FOR TABLE inventory_partitioned.products "
+                                    + " WITH (publish_via_partition_root=true)",
+                            publicationName));
+            statement.execute(
+                    String.format(
+                            "select pg_create_logical_replication_slot('%s','pgoutput');",
+                            slotName));
+        }
+
+        String sourceDDL =
+                String.format(
+                        "CREATE TABLE debezium_source ("
+                                + " id INT NOT NULL,"
+                                + " name STRING,"
+                                + " description STRING,"
+                                + " weight DECIMAL(10,3),"
+                                + " country STRING"
+                                + ") WITH ("
+                                + " 'connector' = 'postgres-cdc',"
+                                + " 'hostname' = '%s',"
+                                + " 'port' = '%s',"
+                                + " 'username' = '%s',"
+                                + " 'password' = '%s',"
+                                + " 'database-name' = '%s',"
+                                + " 'schema-name' = '%s',"
+                                + " 'table-name' = '%s',"
+                                + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'scan.include-partitioned-tables.enabled' = 'true',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
+                                + " 'debezium.publication.name'  = '%s',"
+                                + " 'slot.name' = '%s'"
+                                + ")",
+                        POSTGRES_CONTAINER.getHost(),
+                        POSTGRES_CONTAINER.getMappedPort(POSTGRESQL_PORT),
+                        POSTGRES_CONTAINER.getUsername(),
+                        POSTGRES_CONTAINER.getPassword(),
+                        POSTGRES_CONTAINER.getDatabaseName(),
+                        "inventory_partitioned",
+                        "products",
+                        parallelismSnapshot,
+                        publicationName,
+                        slotName);
+        String sinkDDL =
+                "CREATE TABLE sink ("
+                        + " id INT NOT NULL,"
+                        + " name STRING,"
+                        + " description STRING,"
+                        + " weight DECIMAL(10,3),"
+                        + " country STRING,"
+                        + " PRIMARY KEY (id, country) NOT ENFORCED"
+                        + ") WITH ("
+                        + " 'connector' = 'values',"
+                        + " 'sink-insert-only' = 'false',"
+                        + " 'sink-expected-messages-num' = '20'"
+                        + ")";
+        tEnv.executeSql(sourceDDL);
+        tEnv.executeSql(sinkDDL);
+
+        // async submit job
+        TableResult result =
+                tEnv.executeSql(
+                        "INSERT INTO sink SELECT id, name, description, weight, country FROM debezium_source");
+
+        waitForSnapshotStarted("sink");
+
+        // wait a bit to make sure the replication slot is ready
+        Thread.sleep(5000);
+
+        // generate WAL
+        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+                Statement statement = connection.createStatement()) {
+            statement.execute(
+                    "INSERT INTO inventory_partitioned.products VALUES (default,'jacket','water resistent white wind breaker',0.2, 'us');"); // 110
+            statement.execute(
+                    "INSERT INTO inventory_partitioned.products VALUES (default,'scooter','Big 2-wheel scooter ',5.18, 'uk');");
+            statement.execute(
+                    "CREATE TABLE inventory_partitioned.products_china PARTITION OF inventory_partitioned.products FOR VALUES IN ('china');");
+            statement.execute(
+                    "INSERT INTO inventory_partitioned.products VALUES (default,'bike','Big 2-wheel bycicle ',6.18, 'china');");
+        }
+
+        waitForSinkSize("sink", 11);
+
+        // consume both snapshot and wal events
+        String[] expected =
+                new String[] {
+                    "101,scooter,Small 2-wheel scooter,3.140,us",
+                    "102,car battery,12V car battery,8.100,us",
+                    "103,12-pack drill bits,12-pack of drill bits with sizes ranging from #40 to #3,0.800,us",
+                    "104,hammer,12oz carpenter's hammer,0.750,us",
+                    "105,hammer,14oz carpenter's hammer,0.875,us",
+                    "106,hammer,16oz carpenter's hammer,1.000,uk",
+                    "107,rocks,box of assorted rocks,5.300,uk",
+                    "108,jacket,water resistent black wind breaker,0.100,uk",
+                    "109,spare tire,24 inch spare tire,22.200,uk",
+                    "110,jacket,water resistent white wind breaker,0.200,us",
+                    "111,scooter,Big 2-wheel scooter ,5.180,uk",
+                    "112,bike,Big 2-wheel bycicle ,6.180,china"
+                };
+
+        List<String> actual = TestValuesTableFactory.getResultsAsStrings("sink");
+        Assertions.assertThat(actual).containsExactlyInAnyOrder(expected);
+
+        result.getJobClient().get().cancel().get();
+    }
+
     @ParameterizedTest
     @ValueSource(booleans = {true})
     void testStartupFromLatestOffset(boolean parallelismSnapshot) throws Exception {
@@ -306,10 +424,9 @@ class PostgreSQLConnectorITCase extends PostgresTestBase {
         result.getJobClient().get().cancel().get();
     }
 
-    @ParameterizedTest
-    @ValueSource(booleans = {true})
-    public void testStartupFromCommittedOffset(boolean parallelismSnapshot) throws Exception {
-        setup(parallelismSnapshot);
+    @Test
+    public void testStartupFromCommittedOffset() throws Exception {
+        setup(true);
         initializePostgresTable(POSTGRES_CONTAINER, "inventory");
         try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
                 Statement statement = connection.createStatement()) {
@@ -325,7 +442,9 @@ class PostgreSQLConnectorITCase extends PostgresTestBase {
         String publicName = "dbz_publication_" + new Random().nextInt(1000);
         try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
                 Statement statement = connection.createStatement()) {
-            // TODO: Remove it after adding publication to an existing replication slot.
+            // For pgoutput specifically, the publication must be created before the slot.
+            // postgres community is still working on it:
+            // https://www.postgresql.org/message-id/CALDaNm0-n8FGAorM%2BbTxkzn%2BAOUyx5%3DL_XmnvOP6T24%2B-NcBKg%40mail.gmail.com
             statement.execute(
                     String.format(
                             "CREATE PUBLICATION %s FOR TABLE inventory.products", publicName));
