@@ -17,23 +17,16 @@
 
 package org.apache.flink.cdc.pipeline.tests;
 
-import org.apache.flink.cdc.common.test.utils.TestUtils;
-import org.apache.flink.cdc.connectors.mysql.testutils.MySqlContainer;
-import org.apache.flink.cdc.connectors.mysql.testutils.MySqlVersion;
 import org.apache.flink.cdc.connectors.mysql.testutils.UniqueDatabase;
 import org.apache.flink.cdc.pipeline.tests.utils.PipelineTestEnvironment;
 
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.testcontainers.containers.output.Slf4jLogConsumer;
-import org.testcontainers.containers.output.ToStringConsumer;
 
-import java.nio.file.Path;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.Statement;
@@ -41,53 +34,28 @@ import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
-import java.util.concurrent.TimeoutException;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
 /** E2e tests for Schema Evolution cases. */
-public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
+class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     private static final Logger LOG = LoggerFactory.getLogger(SchemaEvolveE2eITCase.class);
 
-    // ------------------------------------------------------------------------------------------
-    // MySQL Variables (we always use MySQL as the data source for easier verifying)
-    // ------------------------------------------------------------------------------------------
-    protected static final String MYSQL_TEST_USER = "mysqluser";
-    protected static final String MYSQL_TEST_PASSWORD = "mysqlpw";
-    protected static final String INTER_CONTAINER_MYSQL_ALIAS = "mysql";
-    protected static final long EVENT_WAITING_TIMEOUT = 60000L;
-
-    @ClassRule
-    public static final MySqlContainer MYSQL =
-            (MySqlContainer)
-                    new MySqlContainer(
-                                    MySqlVersion.V8_0) // v8 support both ARM and AMD architectures
-                            .withConfigurationOverride("docker/mysql/my.cnf")
-                            .withSetupSQL("docker/mysql/setup.sql")
-                            .withDatabaseName("flink-test")
-                            .withUsername("flinkuser")
-                            .withPassword("flinkpw")
-                            .withNetwork(NETWORK)
-                            .withNetworkAliases(INTER_CONTAINER_MYSQL_ALIAS)
-                            .withLogConsumer(new Slf4jLogConsumer(LOG));
-
     protected final UniqueDatabase schemaEvolveDatabase =
             new UniqueDatabase(MYSQL, "schema_evolve", MYSQL_TEST_USER, MYSQL_TEST_PASSWORD);
 
-    @Before
+    @BeforeEach
     public void before() throws Exception {
         super.before();
         schemaEvolveDatabase.createAndInitialize();
     }
 
-    @After
+    @AfterEach
     public void after() {
         super.after();
         schemaEvolveDatabase.dropDatabase();
     }
 
     @Test
-    public void testSchemaEvolve() throws Exception {
+    void testSchemaEvolve() throws Exception {
         testGenericSchemaEvolution(
                 "evolve",
                 false,
@@ -107,7 +75,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testSchemaEvolveWithIncompatibleChanges() throws Exception {
+    void testSchemaEvolveWithIncompatibleChanges() throws Exception {
         testGenericSchemaEvolution(
                 "evolve",
                 true,
@@ -124,7 +92,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testSchemaEvolveWithException() throws Exception {
+    void testSchemaEvolveWithException() throws Exception {
         testGenericSchemaEvolution(
                 "evolve",
                 false,
@@ -138,7 +106,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testSchemaTryEvolveWithException() throws Exception {
+    void testSchemaTryEvolveWithException() throws Exception {
         testGenericSchemaEvolution(
                 "try_evolve",
                 false,
@@ -160,7 +128,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testSchemaIgnore() throws Exception {
+    void testSchemaIgnore() throws Exception {
 
         testGenericSchemaEvolution(
                 "ignore",
@@ -174,7 +142,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testSchemaException() throws Exception {
+    void testSchemaException() throws Exception {
         testGenericSchemaEvolution(
                 "exception",
                 false,
@@ -187,7 +155,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testLenientSchemaEvolution() throws Exception {
+    void testLenientSchemaEvolution() throws Exception {
 
         testGenericSchemaEvolution(
                 "lenient",
@@ -203,14 +171,15 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         "DataChangeEvent{tableId=%s.members, before=[], after=[1013, Fiona, null, null, 16.0, null], op=INSERT, meta=()}",
                         "DataChangeEvent{tableId=%s.members, before=[], after=[1014, Gem, null, null, 17.0, null], op=INSERT, meta=()}"));
 
-        assertNotExists(
-                Collections.singletonList(
-                        "Applied schema change event DropTableEvent{tableId=%s.members}"),
-                taskManagerConsumer);
+        Assertions.assertThat(taskManagerConsumer.toString())
+                .doesNotContain(
+                        String.format(
+                                "Applied schema change event DropTableEvent{tableId=%s.members}",
+                                schemaEvolveDatabase.getDatabaseName()));
     }
 
     @Test
-    public void testFineGrainedSchemaEvolution() throws Exception {
+    void testFineGrainedSchemaEvolution() throws Exception {
 
         testGenericSchemaEvolution(
                 "evolve",
@@ -232,7 +201,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
     }
 
     @Test
-    public void testLenientWithRoute() throws Exception {
+    void testLenientWithRoute() throws Exception {
         String dbName = schemaEvolveDatabase.getDatabaseName();
 
         String pipelineJob =
@@ -263,10 +232,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         dbName,
                         dbName,
                         parallelism);
-        Path mysqlCdcJar = TestUtils.getResource("mysql-cdc-pipeline-connector.jar");
-        Path valuesCdcJar = TestUtils.getResource("values-cdc-pipeline-connector.jar");
-        Path mysqlDriverJar = TestUtils.getResource("mysql-driver.jar");
-        submitPipelineJob(pipelineJob, mysqlCdcJar, valuesCdcJar, mysqlDriverJar);
+        submitPipelineJob(pipelineJob);
         waitUntilJobRunning(Duration.ofSeconds(30));
         LOG.info("Pipeline job is running");
         validateSnapshotData(dbName, "redirect");
@@ -315,16 +281,16 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         "DataChangeEvent{tableId=%s.redirect, before=[], after=[1013, Fiona, null, null, 16.0, null], op=INSERT, meta=()}",
                         "DataChangeEvent{tableId=%s.redirect, before=[], after=[1014, Gem, null, null, 17.0, null], op=INSERT, meta=()}");
 
-        List<String> expectedTmEvents =
+        String[] expectedTmEvents =
                 expectedTaskManagerEvents.stream()
                         .map(s -> String.format(s, dbName, dbName))
-                        .collect(Collectors.toList());
+                        .toArray(String[]::new);
 
-        validateResult(expectedTmEvents, taskManagerConsumer);
+        validateResult(expectedTmEvents);
     }
 
     @Test
-    public void testUnexpectedBehavior() {
+    void testUnexpectedBehavior() {
         String pipelineJob =
                 String.format(
                         "source:\n"
@@ -348,18 +314,14 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         MYSQL_TEST_PASSWORD,
                         schemaEvolveDatabase.getDatabaseName(),
                         parallelism);
-        Path mysqlCdcJar = TestUtils.getResource("mysql-cdc-pipeline-connector.jar");
-        Path valuesCdcJar = TestUtils.getResource("values-cdc-pipeline-connector.jar");
-        Path mysqlDriverJar = TestUtils.getResource("mysql-driver.jar");
 
         // Submitting job should fail given an unknown schema change behavior configuration
-        Assert.assertThrows(
-                AssertionError.class,
-                () -> submitPipelineJob(pipelineJob, mysqlCdcJar, valuesCdcJar, mysqlDriverJar));
+        Assertions.assertThatThrownBy(() -> submitPipelineJob(pipelineJob))
+                .isExactlyInstanceOf(AssertionError.class);
     }
 
     @Test
-    public void testByDefaultTransform() throws Exception {
+    void testByDefaultTransform() throws Exception {
         String dbName = schemaEvolveDatabase.getDatabaseName();
 
         // We put a dummy transform block that matches nothing
@@ -391,10 +353,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         MYSQL_TEST_PASSWORD,
                         dbName,
                         parallelism);
-        Path mysqlCdcJar = TestUtils.getResource("mysql-cdc-pipeline-connector.jar");
-        Path valuesCdcJar = TestUtils.getResource("values-cdc-pipeline-connector.jar");
-        Path mysqlDriverJar = TestUtils.getResource("mysql-driver.jar");
-        submitPipelineJob(pipelineJob, mysqlCdcJar, valuesCdcJar, mysqlDriverJar);
+        submitPipelineJob(pipelineJob);
         waitUntilJobRunning(Duration.ofSeconds(30));
         LOG.info("Pipeline job is running");
         validateSnapshotData(dbName, "members");
@@ -446,12 +405,12 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         "DataChangeEvent{tableId=%s.members, before=[], after=[1014, Gem, 17.0], op=INSERT, meta=()}",
                         "DropTableEvent{tableId=%s.members}");
 
-        List<String> expectedTmEvents =
+        String[] expectedTmEvents =
                 expectedTaskManagerEvents.stream()
                         .map(s -> String.format(s, dbName, dbName))
-                        .collect(Collectors.toList());
+                        .toArray(String[]::new);
 
-        validateResult(expectedTmEvents, taskManagerConsumer);
+        validateResult(expectedTmEvents);
     }
 
     private void testGenericSchemaEvolution(
@@ -517,10 +476,7 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
                         mergeTable ? "(members|new_members)" : "members",
                         behavior,
                         parallelism);
-        Path mysqlCdcJar = TestUtils.getResource("mysql-cdc-pipeline-connector.jar");
-        Path valuesCdcJar = TestUtils.getResource("values-cdc-pipeline-connector.jar");
-        Path mysqlDriverJar = TestUtils.getResource("mysql-driver.jar");
-        submitPipelineJob(pipelineJob, mysqlCdcJar, valuesCdcJar, mysqlDriverJar);
+        submitPipelineJob(pipelineJob);
         waitUntilJobRunning(Duration.ofSeconds(30));
         LOG.info("Pipeline job is running");
         validateSnapshotData(dbName, mergeTable ? "merged" : "members");
@@ -559,33 +515,29 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
             stmt.execute("DROP TABLE members;");
         }
 
-        List<String> expectedTmEvents =
+        String[] expectedTmEvents =
                 expectedTaskManagerEvents.stream()
                         .map(s -> String.format(s, dbName, dbName))
-                        .collect(Collectors.toList());
+                        .toArray(String[]::new);
 
-        validateResult(expectedTmEvents, taskManagerConsumer);
+        validateResult(taskManagerConsumer, expectedTmEvents);
 
-        List<String> expectedJmEvents =
+        String[] expectedJmEvents =
                 expectedJobManagerEvents.stream()
                         .map(s -> String.format(s, dbName, dbName, dbName))
-                        .collect(Collectors.toList());
+                        .toArray(String[]::new);
 
-        validateResult(expectedJmEvents, jobManagerConsumer);
+        validateResult(jobManagerConsumer, expectedJmEvents);
     }
 
     private void validateSnapshotData(String dbName, String tableName) throws Exception {
-        List<String> expected =
-                Stream.of(
-                                "CreateTableEvent{tableId=%s.%s, schema=columns={`id` INT NOT NULL,`name` VARCHAR(17),`age` INT}, primaryKeys=id, options=()}",
-                                "DataChangeEvent{tableId=%s.%s, before=[], after=[1008, Alice, 21], op=INSERT, meta=()}",
-                                "DataChangeEvent{tableId=%s.%s, before=[], after=[1009, Bob, 20], op=INSERT, meta=()}",
-                                "DataChangeEvent{tableId=%s.%s, before=[], after=[1010, Carol, 19], op=INSERT, meta=()}",
-                                "DataChangeEvent{tableId=%s.%s, before=[], after=[1011, Derrida, 18], op=INSERT, meta=()}")
-                        .map(s -> String.format(s, dbName, tableName))
-                        .collect(Collectors.toList());
-
-        validateResult(expected, taskManagerConsumer);
+        validateResult(
+                s -> String.format(s, dbName, tableName),
+                "CreateTableEvent{tableId=%s.%s, schema=columns={`id` INT NOT NULL,`name` VARCHAR(17),`age` INT}, primaryKeys=id, options=()}",
+                "DataChangeEvent{tableId=%s.%s, before=[], after=[1008, Alice, 21], op=INSERT, meta=()}",
+                "DataChangeEvent{tableId=%s.%s, before=[], after=[1009, Bob, 20], op=INSERT, meta=()}",
+                "DataChangeEvent{tableId=%s.%s, before=[], after=[1010, Carol, 19], op=INSERT, meta=()}",
+                "DataChangeEvent{tableId=%s.%s, before=[], after=[1011, Derrida, 18], op=INSERT, meta=()}");
     }
 
     private void waitForIncrementalStage(String dbName, String tableName, Statement stmt)
@@ -594,45 +546,9 @@ public class SchemaEvolveE2eITCase extends PipelineTestEnvironment {
 
         // Ensure we change schema after incremental stage
         waitUntilSpecificEvent(
+                taskManagerConsumer,
                 String.format(
                         "DataChangeEvent{tableId=%s.%s, before=[], after=[0, __fence__, 0], op=INSERT, meta=()}",
-                        dbName, tableName),
-                taskManagerConsumer);
-    }
-
-    private void validateResult(List<String> expectedEvents, ToStringConsumer consumer)
-            throws Exception {
-        for (String event : expectedEvents) {
-            waitUntilSpecificEvent(event, consumer);
-        }
-    }
-
-    private void assertNotExists(List<String> unexpectedEvents, ToStringConsumer consumer) {
-        String consumerLog = consumer.toUtf8String();
-        for (String event : unexpectedEvents) {
-            Assert.assertFalse(
-                    consumerLog.contains(
-                            String.format(event, schemaEvolveDatabase.getDatabaseName())));
-        }
-    }
-
-    private void waitUntilSpecificEvent(String event, ToStringConsumer consumer) throws Exception {
-        boolean result = false;
-        long endTimeout = System.currentTimeMillis() + SchemaEvolveE2eITCase.EVENT_WAITING_TIMEOUT;
-        while (System.currentTimeMillis() < endTimeout) {
-            String stdout = consumer.toUtf8String();
-            if (stdout.contains(event + "\n")) {
-                result = true;
-                break;
-            }
-            Thread.sleep(1000);
-        }
-        if (!result) {
-            throw new TimeoutException(
-                    "failed to get specific event: "
-                            + event
-                            + " from stdout: "
-                            + consumer.toUtf8String());
-        }
+                        dbName, tableName));
     }
 }
