@@ -23,9 +23,10 @@ import org.apache.flink.cdc.connectors.oracle.source.OracleSourceITCase;
 import org.apache.flink.cdc.connectors.tests.utils.FlinkContainerTestEnvironment;
 
 import io.debezium.relational.TableId;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.DockerClientFactory;
@@ -63,10 +64,9 @@ import static org.apache.flink.cdc.connectors.oracle.source.OracleSourceTestBase
 import static org.apache.flink.cdc.connectors.oracle.source.OracleSourceTestBase.TEST_USER;
 import static org.apache.flink.cdc.connectors.oracle.source.OracleSourceTestBase.TOP_SECRET;
 import static org.apache.flink.cdc.connectors.oracle.source.OracleSourceTestBase.TOP_USER;
-import static org.junit.Assert.assertNotNull;
 
 /** End-to-end tests for oracle-cdc connector uber jar. */
-public class OracleE2eITCase extends FlinkContainerTestEnvironment {
+class OracleE2eITCase extends FlinkContainerTestEnvironment {
 
     private static final Logger LOG = LoggerFactory.getLogger(OracleE2eITCase.class);
     protected static final Pattern COMMENT_PATTERN = Pattern.compile("^(.*)--.*$");
@@ -79,7 +79,7 @@ public class OracleE2eITCase extends FlinkContainerTestEnvironment {
     public static final String ORACLE_IMAGE = "goodboy008/oracle-19.3.0-ee";
     private static OracleContainer oracle;
 
-    @Before
+    @BeforeEach
     public void before() {
         super.before();
         LOG.info("Starting containers...");
@@ -109,7 +109,7 @@ public class OracleE2eITCase extends FlinkContainerTestEnvironment {
         LOG.info("Containers are started.");
     }
 
-    @After
+    @AfterEach
     public void after() {
         if (oracle != null) {
             oracle.stop();
@@ -118,7 +118,7 @@ public class OracleE2eITCase extends FlinkContainerTestEnvironment {
     }
 
     @Test
-    public void testOracleCDC() throws Exception {
+    void testOracleCDC() throws Exception {
         List<String> sqlLines =
                 Arrays.asList(
                         "SET 'execution.checkpointing.interval' = '3s';",
@@ -225,7 +225,7 @@ public class OracleE2eITCase extends FlinkContainerTestEnvironment {
     private static void initializeOracleTable(String sqlFile) {
         final String ddlFile = String.format("ddl/%s.sql", sqlFile);
         final URL ddlTestFile = OracleSourceITCase.class.getClassLoader().getResource(ddlFile);
-        assertNotNull("Cannot locate " + ddlFile, ddlTestFile);
+        Assertions.assertThat(ddlTestFile).withFailMessage("Cannot locate " + ddlFile).isNotNull();
         try (Connection connection = getOracleJdbcConnection();
                 Statement statement = connection.createStatement()) {
             connection.setAutoCommit(true);
