@@ -83,7 +83,6 @@ import java.util.Objects;
 import java.util.Properties;
 import java.util.Set;
 import java.util.stream.Collectors;
-import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 import static org.apache.flink.cdc.common.utils.StringUtils.isNullOrWhitespaceOnly;
@@ -95,6 +94,8 @@ public class TransformParser {
     private static final Logger LOG = LoggerFactory.getLogger(TransformParser.class);
     private static final String DEFAULT_SCHEMA = "default_schema";
     private static final String DEFAULT_TABLE = "TB";
+    private static final String MAPPED_COLUMN_NAME_PREFIX = "$";
+    private static final String MAPPED_SINGLE_COLUMN_NAME = MAPPED_COLUMN_NAME_PREFIX + "0";
 
     private static SqlParser getCalciteParser(String sql) {
         return SqlParser.create(
@@ -126,6 +127,8 @@ public class TransformParser {
                 Class<?> clazz = Class.forName(udf.getClasspath());
                 SqlReturnTypeInference returnTypeInference;
                 ScalarFunction function = ScalarFunctionImpl.create(clazz, "eval");
+                Preconditions.checkNotNull(
+                        function, "UDF function must provide at least one `eval` method.");
                 if (udf.getReturnTypeHint() != null) {
                     // This UDF has return type hint annotation
                     returnTypeInference =
@@ -184,7 +187,7 @@ public class TransformParser {
     }
 
     public static SqlSelect parseSelect(String statement) {
-        SqlNode sqlNode = null;
+        SqlNode sqlNode;
         try {
             sqlNode = getCalciteParser(statement).parseQuery();
         } catch (SqlParseException e) {
@@ -283,17 +286,19 @@ public class TransformParser {
 
         expandWildcard(sqlSelect, columns);
         RelNode relNode = sqlToRel(columns, sqlSelect, udfDescriptors, supportedMetadataColumns);
-        Map<String, RelDataType> relDataTypeMap =
+        RelDataType[] relDataTypes =
                 relNode.getRowType().getFieldList().stream()
-                        .collect(
-                                Collectors.toMap(
-                                        RelDataTypeField::getName, RelDataTypeField::getType));
+                        .map(RelDataTypeField::getType)
+                        .toArray(RelDataType[]::new);
         Map<String, Column> originalColumnMap =
                 columns.stream().collect(Collectors.toMap(Column::getName, column -> column));
         List<ProjectionColumn> projectionColumns = new ArrayList<>();
         Map<String, Integer> addedProjectionColumnNames = new HashMap<>();
 
-        for (SqlNode sqlNode : sqlSelect.getSelectList()) {
+        SqlNodeList selectExpressionList = sqlSelect.getSelectList();
+        for (int i = 0; i < selectExpressionList.size(); i++) {
+            SqlNode sqlNode = selectExpressionList.get(i);
+            RelDataType relDataType = relDataTypes[i];
             ProjectionColumn projectionColumn;
 
             // A projection column could be <EXPR> AS <IDENTIFIER>...
@@ -328,21 +333,24 @@ public class TransformParser {
                             identifierExprNode.names.get(identifierExprNode.names.size() - 1);
                     projectionColumn =
                             resolveProjectionColumnFromIdentifier(
-                                    relDataTypeMap,
+                                    relDataType,
                                     originalColumnMap,
                                     originalName,
                                     columnName,
                                     supportedMetadataColumns);
                 } else {
+                    List<String> originalColumnNames = parseColumnNameList(exprNode);
+                    Map<String, String> columnNameMap = generateColumnNameMap(originalColumnNames);
                     projectionColumn =
                             ProjectionColumn.ofCalculated(
                                     columnName,
                                     DataTypeConverter.convertCalciteRelDataTypeToDataType(
-                                            relDataTypeMap.get(columnName)),
+                                            relDataType),
                                     exprNode.toString(),
                                     JaninoCompiler.translateSqlNodeToJaninoExpression(
-                                            exprNode, udfDescriptors),
-                                    parseColumnNameList(exprNode));
+                                            exprNode, udfDescriptors, columnNameMap),
+                                    originalColumnNames,
+                                    columnNameMap);
                 }
             }
             // ... or an existing column's name identifier.
@@ -351,7 +359,7 @@ public class TransformParser {
                 String columnName = sqlIdentifier.names.get(sqlIdentifier.names.size() - 1);
                 projectionColumn =
                         resolveProjectionColumnFromIdentifier(
-                                relDataTypeMap,
+                                relDataType,
                                 originalColumnMap,
                                 columnName,
                                 columnName,
@@ -379,22 +387,23 @@ public class TransformParser {
      * column or a metadata column).
      */
     public static ProjectionColumn resolveProjectionColumnFromIdentifier(
-            Map<String, RelDataType> relDataTypeMap,
+            RelDataType relDataType,
             Map<String, Column> originalColumnMap,
             String identifier,
             String projectedColumnName,
             SupportedMetadataColumn[] supportedMetadataColumns) {
+        Map<String, String> columnNameMap =
+                Collections.singletonMap(identifier, MAPPED_SINGLE_COLUMN_NAME);
         if (isMetadataColumn(identifier, supportedMetadataColumns)) {
             // For a metadata column, we simply generate a projection column with the same
             return ProjectionColumn.ofCalculated(
                     projectedColumnName,
                     // Metadata columns should never be null
-                    DataTypeConverter.convertCalciteRelDataTypeToDataType(
-                                    relDataTypeMap.get(projectedColumnName))
-                            .notNull(),
+                    DataTypeConverter.convertCalciteRelDataTypeToDataType(relDataType).notNull(),
                     identifier,
-                    identifier,
-                    Collections.singletonList(identifier));
+                    columnNameMap.get(identifier),
+                    Collections.singletonList(identifier),
+                    columnNameMap);
         }
 
         Preconditions.checkArgument(
@@ -404,14 +413,17 @@ public class TransformParser {
 
         Column column = originalColumnMap.get(identifier);
         if (Objects.equals(identifier, projectedColumnName)) {
-            return ProjectionColumn.ofForwarded(column);
+            return ProjectionColumn.ofForwarded(column, MAPPED_SINGLE_COLUMN_NAME);
         } else {
-            return ProjectionColumn.ofAliased(column, projectedColumnName);
+            return ProjectionColumn.ofAliased(
+                    column, projectedColumnName, MAPPED_SINGLE_COLUMN_NAME);
         }
     }
 
     public static String translateFilterExpressionToJaninoExpression(
-            String filterExpression, List<UserDefinedFunctionDescriptor> udfDescriptors) {
+            String filterExpression,
+            List<UserDefinedFunctionDescriptor> udfDescriptors,
+            Map<String, String> columnNameMap) {
         if (isNullOrWhitespaceOnly(filterExpression)) {
             return "";
         }
@@ -420,7 +432,8 @@ public class TransformParser {
             return "";
         }
         SqlNode where = sqlSelect.getWhere();
-        return JaninoCompiler.translateSqlNodeToJaninoExpression(where, udfDescriptors);
+        return JaninoCompiler.translateSqlNodeToJaninoExpression(
+                where, udfDescriptors, columnNameMap);
     }
 
     public static List<String> parseComputedColumnNames(
@@ -450,7 +463,7 @@ public class TransformParser {
                     }
                     columnNames.add(columnName);
                 } else {
-                    throw new ParseException("Unrecognized projection: " + sqlBasicCall.toString());
+                    throw new ParseException("Unrecognized projection: " + sqlBasicCall);
                 }
             } else if (sqlNode instanceof SqlIdentifier) {
                 String columnName = sqlNode.toString();
@@ -549,77 +562,6 @@ public class TransformParser {
         return parseSelect(statement.toString());
     }
 
-    public static SqlNode rewriteExpression(SqlNode sqlNode, Map<String, SqlNode> replaceMap) {
-        if (sqlNode instanceof SqlCall) {
-            SqlCall sqlCall = (SqlCall) sqlNode;
-
-            List<SqlNode> operands = sqlCall.getOperandList();
-            IntStream.range(0, sqlCall.operandCount())
-                    .forEach(
-                            i ->
-                                    sqlCall.setOperand(
-                                            i, rewriteExpression(operands.get(i), replaceMap)));
-            return sqlCall;
-        } else if (sqlNode instanceof SqlIdentifier) {
-            SqlIdentifier sqlIdentifier = (SqlIdentifier) sqlNode;
-            if (sqlIdentifier.names.size() == 1) {
-                String name = sqlIdentifier.names.get(0);
-                if (replaceMap.containsKey(name)) {
-                    return replaceMap.get(name);
-                }
-            }
-            return sqlIdentifier;
-        } else if (sqlNode instanceof SqlNodeList) {
-            SqlNodeList sqlNodeList = (SqlNodeList) sqlNode;
-            IntStream.range(0, sqlNodeList.size())
-                    .forEach(
-                            i ->
-                                    sqlNodeList.set(
-                                            i, rewriteExpression(sqlNodeList.get(i), replaceMap)));
-            return sqlNodeList;
-        } else {
-            return sqlNode;
-        }
-    }
-
-    // Filter expression might hold reference to a calculated column, which causes confusion about
-    // the sequence of projection and filtering operations. This function rewrites filtering about
-    // calculated columns to circumvent this problem.
-    public static String normalizeFilter(String projection, String filter) {
-        if (isNullOrWhitespaceOnly(projection) || isNullOrWhitespaceOnly(filter)) {
-            return filter;
-        }
-
-        SqlSelect sqlSelect = parseProjectionExpression(projection);
-        if (sqlSelect.getSelectList().isEmpty()) {
-            return filter;
-        }
-
-        Map<String, SqlNode> calculatedExpression = new HashMap<>();
-        for (SqlNode sqlNode : sqlSelect.getSelectList()) {
-            if (sqlNode instanceof SqlBasicCall) {
-                SqlBasicCall sqlBasicCall = (SqlBasicCall) sqlNode;
-                if (SqlKind.AS.equals(sqlBasicCall.getOperator().kind)) {
-                    List<SqlNode> operandList = sqlBasicCall.getOperandList();
-                    if (operandList.size() == 2) {
-                        SqlIdentifier alias = (SqlIdentifier) operandList.get(1);
-                        String name = alias.names.get(alias.names.size() - 1);
-                        SqlNode expression = operandList.get(0);
-                        calculatedExpression.put(name, expression);
-                    }
-                }
-            }
-        }
-
-        SqlNode sqlFilter = parseFilterExpression(filter).getWhere();
-        sqlFilter = rewriteExpression(sqlFilter, calculatedExpression);
-        if (sqlFilter != null) {
-            return sqlFilter.toString();
-        } else {
-            return filter;
-        }
-    }
-
     public static boolean hasAsterisk(@Nullable String projection) {
         if (isNullOrWhitespaceOnly(projection)) {
             // Providing an empty projection expression is equivalent to writing `*` explicitly.
@@ -642,4 +584,16 @@ public class TransformParser {
             return false;
         }
     }
+
+    public static Map<String, String> generateColumnNameMap(List<String> originalColumnNames) {
+        int i = 0;
+        Map<String, String> columnNameMap = new HashMap<>();
+        for (String columnName : originalColumnNames) {
+            if (!columnNameMap.containsKey(columnName)) {
+                columnNameMap.put(columnName, MAPPED_COLUMN_NAME_PREFIX + i);
+                i++;
+            }
+        }
+        return columnNameMap;
+    }
 }
