@@ -27,6 +27,7 @@ import org.apache.flink.cdc.common.event.SchemaChangeEvent;
 import org.apache.flink.cdc.common.event.TableId;
 import org.apache.flink.cdc.common.event.TruncateTableEvent;
 import org.apache.flink.cdc.common.pipeline.SchemaChangeBehavior;
+import org.apache.flink.cdc.common.route.RouteRule;
 import org.apache.flink.cdc.common.schema.Column;
 import org.apache.flink.cdc.common.schema.Schema;
 import org.apache.flink.cdc.common.sink.MetadataApplier;
@@ -599,4 +600,113 @@ public class SchemaDerivatorTest extends SchemaTestBase {
                                 new DropTableEvent(NORMALIZE_TEST_TABLE_ID)))
                 .isEmpty();
     }
+
+    @Test
+    void testDeduceMergedCreateTableEvent() {
+        TableIdRouter router =
+                new TableIdRouter(
+                        Arrays.asList(
+                                // Simple 1-to-1 routing rules
+                                new RouteRule("db_1.table_1", "db_1.table_1"),
+                                // Re-routed rules
+                                new RouteRule("db_2.table_1", "db_2.table_2"),
+                                // Merging tables
+                                new RouteRule("db_3.table_\\.*", "db_3.table_merged"),
+                                // Broadcast tables
+                                new RouteRule("db_4.table_1", "db_4.table_a"),
+                                new RouteRule("db_4.table_1", "db_4.table_b")));
+        List<CreateTableEvent> createTableEvents =
+                Arrays.asList(
+                        new CreateTableEvent(
+                                TableId.parse("db_1.table_1"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id1", DataTypes.INT())
+                                        .physicalColumn("name1", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age1", DataTypes.FLOAT())
+                                        .physicalColumn("notes1", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_2.table_1"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id2", DataTypes.INT())
+                                        .physicalColumn("name2", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age2", DataTypes.FLOAT())
+                                        .physicalColumn("notes2", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_3.table_1"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id", DataTypes.INT())
+                                        .physicalColumn("name", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age", DataTypes.FLOAT())
+                                        .physicalColumn("notes", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_3.table_2"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id", DataTypes.INT())
+                                        .physicalColumn("name", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age", DataTypes.FLOAT())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_3.table_3"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id", DataTypes.BIGINT())
+                                        .physicalColumn("name", DataTypes.VARCHAR(200))
+                                        .physicalColumn("age", DataTypes.FLOAT())
+                                        .physicalColumn("notes", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_4.table_1"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id4", DataTypes.INT())
+                                        .physicalColumn("name4", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age4", DataTypes.FLOAT())
+                                        .physicalColumn("notes4", DataTypes.STRING())
+                                        .build()));
+        List<CreateTableEvent> mergedCreateTableEvents =
+                SchemaDerivator.deduceMergedCreateTableEvent(router, createTableEvents);
+        assertThat(mergedCreateTableEvents)
+                .containsExactly(
+                        new CreateTableEvent(
+                                TableId.parse("db_3.table_merged"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id", DataTypes.BIGINT())
+                                        .physicalColumn("name", DataTypes.STRING())
+                                        .physicalColumn("age", DataTypes.FLOAT())
+                                        .physicalColumn("notes", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_4.table_a"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id4", DataTypes.INT())
+                                        .physicalColumn("name4", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age4", DataTypes.FLOAT())
+                                        .physicalColumn("notes4", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_4.table_b"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id4", DataTypes.INT())
+                                        .physicalColumn("name4", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age4", DataTypes.FLOAT())
+                                        .physicalColumn("notes4", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_1.table_1"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id1", DataTypes.INT())
+                                        .physicalColumn("name1", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age1", DataTypes.FLOAT())
+                                        .physicalColumn("notes1", DataTypes.STRING())
+                                        .build()),
+                        new CreateTableEvent(
+                                TableId.parse("db_2.table_2"),
+                                Schema.newBuilder()
+                                        .physicalColumn("id2", DataTypes.INT())
+                                        .physicalColumn("name2", DataTypes.VARCHAR(128))
+                                        .physicalColumn("age2", DataTypes.FLOAT())
+                                        .physicalColumn("notes2", DataTypes.STRING())
+                                        .build()));
+    }
 }
