@@ -29,7 +29,7 @@ import java.util.Collections;
 import java.util.stream.Stream;
 
 /** A test for the {@link EventSerializer}. */
-public class EventSerializerTest extends SerializerTestBase<Event> {
+class EventSerializerTest extends SerializerTestBase<Event> {
     @Override
     protected TypeSerializer<Event> createSerializer() {
         return EventSerializer.INSTANCE;
